<?php
/**
 * Block options class
 *
 * @package Padma_Advanced
 */

namespace Padma_Advanced;

class PadmaVisualElementsFontAwesomeBlockOptions extends \PadmaBlockOptionsAPI {

	/**
	 * Block tabs for options.
	 *
	 * @var array $tabs
	 */
	public $tabs;

	/**
	 * Block sets for options.
	 *
	 * @var array $sets
	 */
	public $sets;

	/**
	 * Inputs for each tab.
	 *
	 * @var array $inputs
	 */
	public $inputs;

	/**
	 * Init block options
	 */
	public function __construct() {

		$this->tabs = array(
			'general' => __( 'General', 'padma-advanced' ),
		);

		$this->sets = array();

		$this->inputs = array(
			'general' => array(

				'url' => array(
					'name'    => 'url',
					'label'   => 'Link',
					'type'    => 'text',
					'tooltip' => 'If set, the icon will be a link',
				),

				'before-icon' => array(
					'name'    => 'before-icon',
					'label'   => 'Before icon',
					'type'    => 'wysiwyg',
					'tooltip' => 'Add content before the icon',
				),

				'after-icon'  => array(
					'name'    => 'after-icon',
					'label'   => 'After icon',
					'type'    => 'wysiwyg',
					'tooltip' => 'Add content after the icon',
				),
				'filter'      => array(
					'name' => 'filter',
					'type' => 'raw_html',
					'html' => '<div class="icon-filter-search"><input type="text" id="icon-filter" placeholder="Filter" title="Filter icons"><a class="icon-filter-reset"><span>x</span></a></div>',
				),
				'fa-icon'     => array(
					'name'    => 'fa-icon',
					'type'    => 'radio',
					'label'   => 'Icon',
					'default' => '',
					'options' => array(
						'fab_fa-500px'                     => '<i class="fab fa-500px"></i>',
						'fab_fa-accessible-icon'           => '<i class="fab fa-accessible-icon"></i>',
						'fab_fa-accusoft'                  => '<i class="fab fa-accusoft"></i>',
						'fab_fa-acquisitions-incorporated' => '<i class="fab fa-acquisitions-incorporated"></i>',
						'fas_fa-ad'                        => '<i class="fas fa-ad"></i>',
						'fas_fa-address-book'              => '<i class="fas fa-address-book"></i>',
						'fas_fa-address-card'              => '<i class="fas fa-address-card"></i>',
						'fas_fa-adjust'                    => '<i class="fas fa-adjust"></i>',
						'fab_fa-adn'                       => '<i class="fab fa-adn"></i>',
						'fab_fa-adobe'                     => '<i class="fab fa-adobe"></i>',
						'fab_fa-adversal'                  => '<i class="fab fa-adversal"></i>',
						'fab_fa-affiliatetheme'            => '<i class="fab fa-affiliatetheme"></i>',
						'fas_fa-air-freshener'             => '<i class="fas fa-air-freshener"></i>',
						'fab_fa-algolia'                   => '<i class="fab fa-algolia"></i>',
						'fas_fa-align-center'              => '<i class="fas fa-align-center"></i>',
						'fas_fa-align-justify'             => '<i class="fas fa-align-justify"></i>',
						'fas_fa-align-left'                => '<i class="fas fa-align-left"></i>',
						'fas_fa-align-right'               => '<i class="fas fa-align-right"></i>',
						'fab_fa-alipay'                    => '<i class="fab fa-alipay"></i>',
						'fas_fa-allergies'                 => '<i class="fas fa-allergies"></i>',
						'fab_fa-amazon'                    => '<i class="fab fa-amazon"></i>',
						'fab_fa-amazon-pay'                => '<i class="fab fa-amazon-pay"></i>',
						'fas_fa-ambulance'                 => '<i class="fas fa-ambulance"></i>',
						'fas_fa-american-sign-language-interpreting' => '<i class="fas fa-american-sign-language-interpreting"></i>',
						'fab_fa-amilia'                    => '<i class="fab fa-amilia"></i>',
						'fas_fa-anchor'                    => '<i class="fas fa-anchor"></i>',
						'fab_fa-android'                   => '<i class="fab fa-android"></i>',
						'fab_fa-angellist'                 => '<i class="fab fa-angellist"></i>',
						'fas_fa-angle-double-down'         => '<i class="fas fa-angle-double-down"></i>',
						'fas_fa-angle-double-left'         => '<i class="fas fa-angle-double-left"></i>',
						'fas_fa-angle-double-right'        => '<i class="fas fa-angle-double-right"></i>',
						'fas_fa-angle-double-up'           => '<i class="fas fa-angle-double-up"></i>',
						'fas_fa-angle-down'                => '<i class="fas fa-angle-down"></i>',
						'fas_fa-angle-left'                => '<i class="fas fa-angle-left"></i>',
						'fas_fa-angle-right'               => '<i class="fas fa-angle-right"></i>',
						'fas_fa-angle-up'                  => '<i class="fas fa-angle-up"></i>',
						'fas_fa-angry'                     => '<i class="fas fa-angry"></i>',
						'fab_fa-angrycreative'             => '<i class="fab fa-angrycreative"></i>',
						'fab_fa-angular'                   => '<i class="fab fa-angular"></i>',
						'fas_fa-ankh'                      => '<i class="fas fa-ankh"></i>',
						'fab_fa-app-store'                 => '<i class="fab fa-app-store"></i>',
						'fab_fa-app-store-ios'             => '<i class="fab fa-app-store-ios"></i>',
						'fab_fa-apper'                     => '<i class="fab fa-apper"></i>',
						'fab_fa-apple'                     => '<i class="fab fa-apple"></i>',
						'fas_fa-apple-alt'                 => '<i class="fas fa-apple-alt"></i>',
						'fab_fa-apple-pay'                 => '<i class="fab fa-apple-pay"></i>',
						'fas_fa-archive'                   => '<i class="fas fa-archive"></i>',
						'fas_fa-archway'                   => '<i class="fas fa-archway"></i>',
						'fas_fa-arrow-alt-circle-down'     => '<i class="fas fa-arrow-alt-circle-down"></i>',
						'fas_fa-arrow-alt-circle-left'     => '<i class="fas fa-arrow-alt-circle-left"></i>',
						'fas_fa-arrow-alt-circle-right'    => '<i class="fas fa-arrow-alt-circle-right"></i>',
						'fas_fa-arrow-alt-circle-up'       => '<i class="fas fa-arrow-alt-circle-up"></i>',
						'fas_fa-arrow-circle-down'         => '<i class="fas fa-arrow-circle-down"></i>',
						'fas_fa-arrow-circle-left'         => '<i class="fas fa-arrow-circle-left"></i>',
						'fas_fa-arrow-circle-right'        => '<i class="fas fa-arrow-circle-right"></i>',
						'fas_fa-arrow-circle-up'           => '<i class="fas fa-arrow-circle-up"></i>',
						'fas_fa-arrow-down'                => '<i class="fas fa-arrow-down"></i>',
						'fas_fa-arrow-left'                => '<i class="fas fa-arrow-left"></i>',
						'fas_fa-arrow-right'               => '<i class="fas fa-arrow-right"></i>',
						'fas_fa-arrow-up'                  => '<i class="fas fa-arrow-up"></i>',
						'fas_fa-arrows-alt'                => '<i class="fas fa-arrows-alt"></i>',
						'fas_fa-arrows-alt-h'              => '<i class="fas fa-arrows-alt-h"></i>',
						'fas_fa-arrows-alt-v'              => '<i class="fas fa-arrows-alt-v"></i>',
						'fab_fa-artstation'                => '<i class="fab fa-artstation"></i>',
						'fas_fa-assistive-listening-systems' => '<i class="fas fa-assistive-listening-systems"></i>',
						'fas_fa-asterisk'                  => '<i class="fas fa-asterisk"></i>',
						'fab_fa-asymmetrik'                => '<i class="fab fa-asymmetrik"></i>',
						'fas_fa-at'                        => '<i class="fas fa-at"></i>',
						'fas_fa-atlas'                     => '<i class="fas fa-atlas"></i>',
						'fab_fa-atlassian'                 => '<i class="fab fa-atlassian"></i>',
						'fas_fa-atom'                      => '<i class="fas fa-atom"></i>',
						'fab_fa-audible'                   => '<i class="fab fa-audible"></i>',
						'fas_fa-audio-description'         => '<i class="fas fa-audio-description"></i>',
						'fab_fa-autoprefixer'              => '<i class="fab fa-autoprefixer"></i>',
						'fab_fa-avianex'                   => '<i class="fab fa-avianex"></i>',
						'fab_fa-aviato'                    => '<i class="fab fa-aviato"></i>',
						'fas_fa-award'                     => '<i class="fas fa-award"></i>',
						'fab_fa-aws'                       => '<i class="fab fa-aws"></i>',
						'fas_fa-baby'                      => '<i class="fas fa-baby"></i>',
						'fas_fa-baby-carriage'             => '<i class="fas fa-baby-carriage"></i>',
						'fas_fa-backspace'                 => '<i class="fas fa-backspace"></i>',
						'fas_fa-backward'                  => '<i class="fas fa-backward"></i>',
						'fas_fa-bacon'                     => '<i class="fas fa-bacon"></i>',
						'fas_fa-balance-scale'             => '<i class="fas fa-balance-scale"></i>',
						'fas_fa-ban'                       => '<i class="fas fa-ban"></i>',
						'fas_fa-band-aid'                  => '<i class="fas fa-band-aid"></i>',
						'fab_fa-bandcamp'                  => '<i class="fab fa-bandcamp"></i>',
						'fas_fa-barcode'                   => '<i class="fas fa-barcode"></i>',
						'fas_fa-bars'                      => '<i class="fas fa-bars"></i>',
						'fas_fa-baseball-ball'             => '<i class="fas fa-baseball-ball"></i>',
						'fas_fa-basketball-ball'           => '<i class="fas fa-basketball-ball"></i>',
						'fas_fa-bath'                      => '<i class="fas fa-bath"></i>',
						'fas_fa-battery-empty'             => '<i class="fas fa-battery-empty"></i>',
						'fas_fa-battery-full'              => '<i class="fas fa-battery-full"></i>',
						'fas_fa-battery-half'              => '<i class="fas fa-battery-half"></i>',
						'fas_fa-battery-quarter'           => '<i class="fas fa-battery-quarter"></i>',
						'fas_fa-battery-three-quarters'    => '<i class="fas fa-battery-three-quarters"></i>',
						'fas_fa-bed'                       => '<i class="fas fa-bed"></i>',
						'fas_fa-beer'                      => '<i class="fas fa-beer"></i>',
						'fab_fa-behance'                   => '<i class="fab fa-behance"></i>',
						'fab_fa-behance-square'            => '<i class="fab fa-behance-square"></i>',
						'fas_fa-bell'                      => '<i class="fas fa-bell"></i>',
						'fas_fa-bell-slash'                => '<i class="fas fa-bell-slash"></i>',
						'fas_fa-bezier-curve'              => '<i class="fas fa-bezier-curve"></i>',
						'fas_fa-bible'                     => '<i class="fas fa-bible"></i>',
						'fas_fa-bicycle'                   => '<i class="fas fa-bicycle"></i>',
						'fab_fa-bimobject'                 => '<i class="fab fa-bimobject"></i>',
						'fas_fa-binoculars'                => '<i class="fas fa-binoculars"></i>',
						'fas_fa-biohazard'                 => '<i class="fas fa-biohazard"></i>',
						'fas_fa-birthday-cake'             => '<i class="fas fa-birthday-cake"></i>',
						'fab_fa-bitbucket'                 => '<i class="fab fa-bitbucket"></i>',
						'fab_fa-bitcoin'                   => '<i class="fab fa-bitcoin"></i>',
						'fab_fa-bity'                      => '<i class="fab fa-bity"></i>',
						'fab_fa-black-tie'                 => '<i class="fab fa-black-tie"></i>',
						'fab_fa-blackberry'                => '<i class="fab fa-blackberry"></i>',
						'fas_fa-blender'                   => '<i class="fas fa-blender"></i>',
						'fas_fa-blender-phone'             => '<i class="fas fa-blender-phone"></i>',
						'fas_fa-blind'                     => '<i class="fas fa-blind"></i>',
						'fas_fa-blog'                      => '<i class="fas fa-blog"></i>',
						'fab_fa-blogger'                   => '<i class="fab fa-blogger"></i>',
						'fab_fa-blogger-b'                 => '<i class="fab fa-blogger-b"></i>',
						'fab_fa-bluetooth'                 => '<i class="fab fa-bluetooth"></i>',
						'fab_fa-bluetooth-b'               => '<i class="fab fa-bluetooth-b"></i>',
						'fas_fa-bold'                      => '<i class="fas fa-bold"></i>',
						'fas_fa-bolt'                      => '<i class="fas fa-bolt"></i>',
						'fas_fa-bomb'                      => '<i class="fas fa-bomb"></i>',
						'fas_fa-bone'                      => '<i class="fas fa-bone"></i>',
						'fas_fa-bong'                      => '<i class="fas fa-bong"></i>',
						'fas_fa-book'                      => '<i class="fas fa-book"></i>',
						'fas_fa-book-dead'                 => '<i class="fas fa-book-dead"></i>',
						'fas_fa-book-medical'              => '<i class="fas fa-book-medical"></i>',
						'fas_fa-book-open'                 => '<i class="fas fa-book-open"></i>',
						'fas_fa-book-reader'               => '<i class="fas fa-book-reader"></i>',
						'fas_fa-bookmark'                  => '<i class="fas fa-bookmark"></i>',
						'fas_fa-bowling-ball'              => '<i class="fas fa-bowling-ball"></i>',
						'fas_fa-box'                       => '<i class="fas fa-box"></i>',
						'fas_fa-box-open'                  => '<i class="fas fa-box-open"></i>',
						'fas_fa-boxes'                     => '<i class="fas fa-boxes"></i>',
						'fas_fa-braille'                   => '<i class="fas fa-braille"></i>',
						'fas_fa-brain'                     => '<i class="fas fa-brain"></i>',
						'fas_fa-bread-slice'               => '<i class="fas fa-bread-slice"></i>',
						'fas_fa-briefcase'                 => '<i class="fas fa-briefcase"></i>',
						'fas_fa-briefcase-medical'         => '<i class="fas fa-briefcase-medical"></i>',
						'fas_fa-broadcast-tower'           => '<i class="fas fa-broadcast-tower"></i>',
						'fas_fa-broom'                     => '<i class="fas fa-broom"></i>',
						'fas_fa-brush'                     => '<i class="fas fa-brush"></i>',
						'fab_fa-btc'                       => '<i class="fab fa-btc"></i>',
						'fas_fa-bug'                       => '<i class="fas fa-bug"></i>',
						'fas_fa-building'                  => '<i class="fas fa-building"></i>',
						'fas_fa-bullhorn'                  => '<i class="fas fa-bullhorn"></i>',
						'fas_fa-bullseye'                  => '<i class="fas fa-bullseye"></i>',
						'fas_fa-burn'                      => '<i class="fas fa-burn"></i>',
						'fab_fa-buromobelexperte'          => '<i class="fab fa-buromobelexperte"></i>',
						'fas_fa-bus'                       => '<i class="fas fa-bus"></i>',
						'fas_fa-bus-alt'                   => '<i class="fas fa-bus-alt"></i>',
						'fas_fa-business-time'             => '<i class="fas fa-business-time"></i>',
						'fab_fa-buysellads'                => '<i class="fab fa-buysellads"></i>',
						'fas_fa-calculator'                => '<i class="fas fa-calculator"></i>',
						'fas_fa-calendar'                  => '<i class="fas fa-calendar"></i>',
						'fas_fa-calendar-alt'              => '<i class="fas fa-calendar-alt"></i>',
						'fas_fa-calendar-check'            => '<i class="fas fa-calendar-check"></i>',
						'fas_fa-calendar-day'              => '<i class="fas fa-calendar-day"></i>',
						'fas_fa-calendar-minus'            => '<i class="fas fa-calendar-minus"></i>',
						'fas_fa-calendar-plus'             => '<i class="fas fa-calendar-plus"></i>',
						'fas_fa-calendar-times'            => '<i class="fas fa-calendar-times"></i>',
						'fas_fa-calendar-week'             => '<i class="fas fa-calendar-week"></i>',
						'fas_fa-camera'                    => '<i class="fas fa-camera"></i>',
						'fas_fa-camera-retro'              => '<i class="fas fa-camera-retro"></i>',
						'fas_fa-campground'                => '<i class="fas fa-campground"></i>',
						'fab_fa-canadian-maple-leaf'       => '<i class="fab fa-canadian-maple-leaf"></i>',
						'fas_fa-candy-cane'                => '<i class="fas fa-candy-cane"></i>',
						'fas_fa-cannabis'                  => '<i class="fas fa-cannabis"></i>',
						'fas_fa-capsules'                  => '<i class="fas fa-capsules"></i>',
						'fas_fa-car'                       => '<i class="fas fa-car"></i>',
						'fas_fa-car-alt'                   => '<i class="fas fa-car-alt"></i>',
						'fas_fa-car-battery'               => '<i class="fas fa-car-battery"></i>',
						'fas_fa-car-crash'                 => '<i class="fas fa-car-crash"></i>',
						'fas_fa-car-side'                  => '<i class="fas fa-car-side"></i>',
						'fas_fa-caret-down'                => '<i class="fas fa-caret-down"></i>',
						'fas_fa-caret-left'                => '<i class="fas fa-caret-left"></i>',
						'fas_fa-caret-right'               => '<i class="fas fa-caret-right"></i>',
						'fas_fa-caret-square-down'         => '<i class="fas fa-caret-square-down"></i>',
						'fas_fa-caret-square-left'         => '<i class="fas fa-caret-square-left"></i>',
						'fas_fa-caret-square-right'        => '<i class="fas fa-caret-square-right"></i>',
						'fas_fa-caret-square-up'           => '<i class="fas fa-caret-square-up"></i>',
						'fas_fa-caret-up'                  => '<i class="fas fa-caret-up"></i>',
						'fas_fa-carrot'                    => '<i class="fas fa-carrot"></i>',
						'fas_fa-cart-arrow-down'           => '<i class="fas fa-cart-arrow-down"></i>',
						'fas_fa-cart-plus'                 => '<i class="fas fa-cart-plus"></i>',
						'fas_fa-cash-register'             => '<i class="fas fa-cash-register"></i>',
						'fas_fa-cat'                       => '<i class="fas fa-cat"></i>',
						'fab_fa-cc-amazon-pay'             => '<i class="fab fa-cc-amazon-pay"></i>',
						'fab_fa-cc-amex'                   => '<i class="fab fa-cc-amex"></i>',
						'fab_fa-cc-apple-pay'              => '<i class="fab fa-cc-apple-pay"></i>',
						'fab_fa-cc-diners-club'            => '<i class="fab fa-cc-diners-club"></i>',
						'fab_fa-cc-discover'               => '<i class="fab fa-cc-discover"></i>',
						'fab_fa-cc-jcb'                    => '<i class="fab fa-cc-jcb"></i>',
						'fab_fa-cc-mastercard'             => '<i class="fab fa-cc-mastercard"></i>',
						'fab_fa-cc-paypal'                 => '<i class="fab fa-cc-paypal"></i>',
						'fab_fa-cc-stripe'                 => '<i class="fab fa-cc-stripe"></i>',
						'fab_fa-cc-visa'                   => '<i class="fab fa-cc-visa"></i>',
						'fab_fa-centercode'                => '<i class="fab fa-centercode"></i>',
						'fab_fa-centos'                    => '<i class="fab fa-centos"></i>',
						'fas_fa-certificate'               => '<i class="fas fa-certificate"></i>',
						'fas_fa-chair'                     => '<i class="fas fa-chair"></i>',
						'fas_fa-chalkboard'                => '<i class="fas fa-chalkboard"></i>',
						'fas_fa-chalkboard-teacher'        => '<i class="fas fa-chalkboard-teacher"></i>',
						'fas_fa-charging-station'          => '<i class="fas fa-charging-station"></i>',
						'fas_fa-chart-area'                => '<i class="fas fa-chart-area"></i>',
						'fas_fa-chart-bar'                 => '<i class="fas fa-chart-bar"></i>',
						'fas_fa-chart-line'                => '<i class="fas fa-chart-line"></i>',
						'fas_fa-chart-pie'                 => '<i class="fas fa-chart-pie"></i>',
						'fas_fa-check'                     => '<i class="fas fa-check"></i>',
						'fas_fa-check-circle'              => '<i class="fas fa-check-circle"></i>',
						'fas_fa-check-double'              => '<i class="fas fa-check-double"></i>',
						'fas_fa-check-square'              => '<i class="fas fa-check-square"></i>',
						'fas_fa-cheese'                    => '<i class="fas fa-cheese"></i>',
						'fas_fa-chess'                     => '<i class="fas fa-chess"></i>',
						'fas_fa-chess-bishop'              => '<i class="fas fa-chess-bishop"></i>',
						'fas_fa-chess-board'               => '<i class="fas fa-chess-board"></i>',
						'fas_fa-chess-king'                => '<i class="fas fa-chess-king"></i>',
						'fas_fa-chess-knight'              => '<i class="fas fa-chess-knight"></i>',
						'fas_fa-chess-pawn'                => '<i class="fas fa-chess-pawn"></i>',
						'fas_fa-chess-queen'               => '<i class="fas fa-chess-queen"></i>',
						'fas_fa-chess-rook'                => '<i class="fas fa-chess-rook"></i>',
						'fas_fa-chevron-circle-down'       => '<i class="fas fa-chevron-circle-down"></i>',
						'fas_fa-chevron-circle-left'       => '<i class="fas fa-chevron-circle-left"></i>',
						'fas_fa-chevron-circle-right'      => '<i class="fas fa-chevron-circle-right"></i>',
						'fas_fa-chevron-circle-up'         => '<i class="fas fa-chevron-circle-up"></i>',
						'fas_fa-chevron-down'              => '<i class="fas fa-chevron-down"></i>',
						'fas_fa-chevron-left'              => '<i class="fas fa-chevron-left"></i>',
						'fas_fa-chevron-right'             => '<i class="fas fa-chevron-right"></i>',
						'fas_fa-chevron-up'                => '<i class="fas fa-chevron-up"></i>',
						'fas_fa-child'                     => '<i class="fas fa-child"></i>',
						'fab_fa-chrome'                    => '<i class="fab fa-chrome"></i>',
						'fas_fa-church'                    => '<i class="fas fa-church"></i>',
						'fas_fa-circle'                    => '<i class="fas fa-circle"></i>',
						'fas_fa-circle-notch'              => '<i class="fas fa-circle-notch"></i>',
						'fas_fa-city'                      => '<i class="fas fa-city"></i>',
						'fas_fa-clinic-medical'            => '<i class="fas fa-clinic-medical"></i>',
						'fas_fa-clipboard'                 => '<i class="fas fa-clipboard"></i>',
						'fas_fa-clipboard-check'           => '<i class="fas fa-clipboard-check"></i>',
						'fas_fa-clipboard-list'            => '<i class="fas fa-clipboard-list"></i>',
						'fas_fa-clock'                     => '<i class="fas fa-clock"></i>',
						'fas_fa-clone'                     => '<i class="fas fa-clone"></i>',
						'fas_fa-closed-captioning'         => '<i class="fas fa-closed-captioning"></i>',
						'fas_fa-cloud'                     => '<i class="fas fa-cloud"></i>',
						'fas_fa-cloud-download-alt'        => '<i class="fas fa-cloud-download-alt"></i>',
						'fas_fa-cloud-meatball'            => '<i class="fas fa-cloud-meatball"></i>',
						'fas_fa-cloud-moon'                => '<i class="fas fa-cloud-moon"></i>',
						'fas_fa-cloud-moon-rain'           => '<i class="fas fa-cloud-moon-rain"></i>',
						'fas_fa-cloud-rain'                => '<i class="fas fa-cloud-rain"></i>',
						'fas_fa-cloud-showers-heavy'       => '<i class="fas fa-cloud-showers-heavy"></i>',
						'fas_fa-cloud-sun'                 => '<i class="fas fa-cloud-sun"></i>',
						'fas_fa-cloud-sun-rain'            => '<i class="fas fa-cloud-sun-rain"></i>',
						'fas_fa-cloud-upload-alt'          => '<i class="fas fa-cloud-upload-alt"></i>',
						'fab_fa-cloudscale'                => '<i class="fab fa-cloudscale"></i>',
						'fab_fa-cloudsmith'                => '<i class="fab fa-cloudsmith"></i>',
						'fab_fa-cloudversify'              => '<i class="fab fa-cloudversify"></i>',
						'fas_fa-cocktail'                  => '<i class="fas fa-cocktail"></i>',
						'fas_fa-code'                      => '<i class="fas fa-code"></i>',
						'fas_fa-code-branch'               => '<i class="fas fa-code-branch"></i>',
						'fab_fa-codepen'                   => '<i class="fab fa-codepen"></i>',
						'fab_fa-codiepie'                  => '<i class="fab fa-codiepie"></i>',
						'fas_fa-coffee'                    => '<i class="fas fa-coffee"></i>',
						'fas_fa-cog'                       => '<i class="fas fa-cog"></i>',
						'fas_fa-cogs'                      => '<i class="fas fa-cogs"></i>',
						'fas_fa-coins'                     => '<i class="fas fa-coins"></i>',
						'fas_fa-columns'                   => '<i class="fas fa-columns"></i>',
						'fas_fa-comment'                   => '<i class="fas fa-comment"></i>',
						'fas_fa-comment-alt'               => '<i class="fas fa-comment-alt"></i>',
						'fas_fa-comment-dollar'            => '<i class="fas fa-comment-dollar"></i>',
						'fas_fa-comment-dots'              => '<i class="fas fa-comment-dots"></i>',
						'fas_fa-comment-medical'           => '<i class="fas fa-comment-medical"></i>',
						'fas_fa-comment-slash'             => '<i class="fas fa-comment-slash"></i>',
						'fas_fa-comments'                  => '<i class="fas fa-comments"></i>',
						'fas_fa-comments-dollar'           => '<i class="fas fa-comments-dollar"></i>',
						'fas_fa-compact-disc'              => '<i class="fas fa-compact-disc"></i>',
						'fas_fa-compass'                   => '<i class="fas fa-compass"></i>',
						'fas_fa-compress'                  => '<i class="fas fa-compress"></i>',
						'fas_fa-compress-arrows-alt'       => '<i class="fas fa-compress-arrows-alt"></i>',
						'fas_fa-concierge-bell'            => '<i class="fas fa-concierge-bell"></i>',
						'fab_fa-confluence'                => '<i class="fab fa-confluence"></i>',
						'fab_fa-connectdevelop'            => '<i class="fab fa-connectdevelop"></i>',
						'fab_fa-contao'                    => '<i class="fab fa-contao"></i>',
						'fas_fa-cookie'                    => '<i class="fas fa-cookie"></i>',
						'fas_fa-cookie-bite'               => '<i class="fas fa-cookie-bite"></i>',
						'fas_fa-copy'                      => '<i class="fas fa-copy"></i>',
						'fas_fa-copyright'                 => '<i class="fas fa-copyright"></i>',
						'fas_fa-couch'                     => '<i class="fas fa-couch"></i>',
						'fab_fa-cpanel'                    => '<i class="fab fa-cpanel"></i>',
						'fab_fa-creative-commons'          => '<i class="fab fa-creative-commons"></i>',
						'fab_fa-creative-commons-by'       => '<i class="fab fa-creative-commons-by"></i>',
						'fab_fa-creative-commons-nc'       => '<i class="fab fa-creative-commons-nc"></i>',
						'fab_fa-creative-commons-nc-eu'    => '<i class="fab fa-creative-commons-nc-eu"></i>',
						'fab_fa-creative-commons-nc-jp'    => '<i class="fab fa-creative-commons-nc-jp"></i>',
						'fab_fa-creative-commons-nd'       => '<i class="fab fa-creative-commons-nd"></i>',
						'fab_fa-creative-commons-pd'       => '<i class="fab fa-creative-commons-pd"></i>',
						'fab_fa-creative-commons-pd-alt'   => '<i class="fab fa-creative-commons-pd-alt"></i>',
						'fab_fa-creative-commons-remix'    => '<i class="fab fa-creative-commons-remix"></i>',
						'fab_fa-creative-commons-sa'       => '<i class="fab fa-creative-commons-sa"></i>',
						'fab_fa-creative-commons-sampling' => '<i class="fab fa-creative-commons-sampling"></i>',
						'fab_fa-creative-commons-sampling-plus' => '<i class="fab fa-creative-commons-sampling-plus"></i>',
						'fab_fa-creative-commons-share'    => '<i class="fab fa-creative-commons-share"></i>',
						'fab_fa-creative-commons-zero'     => '<i class="fab fa-creative-commons-zero"></i>',
						'fas_fa-credit-card'               => '<i class="fas fa-credit-card"></i>',
						'fab_fa-critical-role'             => '<i class="fab fa-critical-role"></i>',
						'fas_fa-crop'                      => '<i class="fas fa-crop"></i>',
						'fas_fa-crop-alt'                  => '<i class="fas fa-crop-alt"></i>',
						'fas_fa-cross'                     => '<i class="fas fa-cross"></i>',
						'fas_fa-crosshairs'                => '<i class="fas fa-crosshairs"></i>',
						'fas_fa-crow'                      => '<i class="fas fa-crow"></i>',
						'fas_fa-crown'                     => '<i class="fas fa-crown"></i>',
						'fas_fa-crutch'                    => '<i class="fas fa-crutch"></i>',
						'fab_fa-css'                       => '<i class="fab fa-css"></i>',
						'fab_fa-css'                       => '<i class="fab fa-css"></i>',
						'fas_fa-cube'                      => '<i class="fas fa-cube"></i>',
						'fas_fa-cubes'                     => '<i class="fas fa-cubes"></i>',
						'fas_fa-cut'                       => '<i class="fas fa-cut"></i>',
						'fab_fa-cuttlefish'                => '<i class="fab fa-cuttlefish"></i>',
						'fab_fa-d-and-d'                   => '<i class="fab fa-d-and-d"></i>',
						'fab_fa-d-and-d-beyond'            => '<i class="fab fa-d-and-d-beyond"></i>',
						'fab_fa-dashcube'                  => '<i class="fab fa-dashcube"></i>',
						'fas_fa-database'                  => '<i class="fas fa-database"></i>',
						'fas_fa-deaf'                      => '<i class="fas fa-deaf"></i>',
						'fab_fa-delicious'                 => '<i class="fab fa-delicious"></i>',
						'fas_fa-democrat'                  => '<i class="fas fa-democrat"></i>',
						'fab_fa-deploydog'                 => '<i class="fab fa-deploydog"></i>',
						'fab_fa-deskpro'                   => '<i class="fab fa-deskpro"></i>',
						'fas_fa-desktop'                   => '<i class="fas fa-desktop"></i>',
						'fab_fa-dev'                       => '<i class="fab fa-dev"></i>',
						'fab_fa-deviantart'                => '<i class="fab fa-deviantart"></i>',
						'fas_fa-dharmachakra'              => '<i class="fas fa-dharmachakra"></i>',
						'fab_fa-dhl'                       => '<i class="fab fa-dhl"></i>',
						'fas_fa-diagnoses'                 => '<i class="fas fa-diagnoses"></i>',
						'fab_fa-diaspora'                  => '<i class="fab fa-diaspora"></i>',
						'fas_fa-dice'                      => '<i class="fas fa-dice"></i>',
						'fas_fa-dice-d'                    => '<i class="fas fa-dice-d"></i>',
						'fas_fa-dice-d'                    => '<i class="fas fa-dice-d"></i>',
						'fas_fa-dice-five'                 => '<i class="fas fa-dice-five"></i>',
						'fas_fa-dice-four'                 => '<i class="fas fa-dice-four"></i>',
						'fas_fa-dice-one'                  => '<i class="fas fa-dice-one"></i>',
						'fas_fa-dice-six'                  => '<i class="fas fa-dice-six"></i>',
						'fas_fa-dice-three'                => '<i class="fas fa-dice-three"></i>',
						'fas_fa-dice-two'                  => '<i class="fas fa-dice-two"></i>',
						'fab_fa-digg'                      => '<i class="fab fa-digg"></i>',
						'fab_fa-digital-ocean'             => '<i class="fab fa-digital-ocean"></i>',
						'fas_fa-digital-tachograph'        => '<i class="fas fa-digital-tachograph"></i>',
						'fas_fa-directions'                => '<i class="fas fa-directions"></i>',
						'fab_fa-discord'                   => '<i class="fab fa-discord"></i>',
						'fab_fa-discourse'                 => '<i class="fab fa-discourse"></i>',
						'fas_fa-divide'                    => '<i class="fas fa-divide"></i>',
						'fas_fa-dizzy'                     => '<i class="fas fa-dizzy"></i>',
						'fas_fa-dna'                       => '<i class="fas fa-dna"></i>',
						'fab_fa-dochub'                    => '<i class="fab fa-dochub"></i>',
						'fab_fa-docker'                    => '<i class="fab fa-docker"></i>',
						'fas_fa-dog'                       => '<i class="fas fa-dog"></i>',
						'fas_fa-dollar-sign'               => '<i class="fas fa-dollar-sign"></i>',
						'fas_fa-dolly'                     => '<i class="fas fa-dolly"></i>',
						'fas_fa-dolly-flatbed'             => '<i class="fas fa-dolly-flatbed"></i>',
						'fas_fa-donate'                    => '<i class="fas fa-donate"></i>',
						'fas_fa-door-closed'               => '<i class="fas fa-door-closed"></i>',
						'fas_fa-door-open'                 => '<i class="fas fa-door-open"></i>',
						'fas_fa-dot-circle'                => '<i class="fas fa-dot-circle"></i>',
						'fas_fa-dove'                      => '<i class="fas fa-dove"></i>',
						'fas_fa-download'                  => '<i class="fas fa-download"></i>',
						'fab_fa-draft'                     => '<i class="fab fa-draft"></i>',
						'fas_fa-drafting-compass'          => '<i class="fas fa-drafting-compass"></i>',
						'fas_fa-dragon'                    => '<i class="fas fa-dragon"></i>',
						'fas_fa-draw-polygon'              => '<i class="fas fa-draw-polygon"></i>',
						'fab_fa-dribbble'                  => '<i class="fab fa-dribbble"></i>',
						'fab_fa-dribbble-square'           => '<i class="fab fa-dribbble-square"></i>',
						'fab_fa-dropbox'                   => '<i class="fab fa-dropbox"></i>',
						'fas_fa-drum'                      => '<i class="fas fa-drum"></i>',
						'fas_fa-drum-steelpan'             => '<i class="fas fa-drum-steelpan"></i>',
						'fas_fa-drumstick-bite'            => '<i class="fas fa-drumstick-bite"></i>',
						'fab_fa-drupal'                    => '<i class="fab fa-drupal"></i>',
						'fas_fa-dumbbell'                  => '<i class="fas fa-dumbbell"></i>',
						'fas_fa-dumpster'                  => '<i class="fas fa-dumpster"></i>',
						'fas_fa-dumpster-fire'             => '<i class="fas fa-dumpster-fire"></i>',
						'fas_fa-dungeon'                   => '<i class="fas fa-dungeon"></i>',
						'fab_fa-dyalog'                    => '<i class="fab fa-dyalog"></i>',
						'fab_fa-earlybirds'                => '<i class="fab fa-earlybirds"></i>',
						'fab_fa-ebay'                      => '<i class="fab fa-ebay"></i>',
						'fab_fa-edge'                      => '<i class="fab fa-edge"></i>',
						'fas_fa-edit'                      => '<i class="fas fa-edit"></i>',
						'fas_fa-egg'                       => '<i class="fas fa-egg"></i>',
						'fas_fa-eject'                     => '<i class="fas fa-eject"></i>',
						'fab_fa-elementor'                 => '<i class="fab fa-elementor"></i>',
						'fas_fa-ellipsis-h'                => '<i class="fas fa-ellipsis-h"></i>',
						'fas_fa-ellipsis-v'                => '<i class="fas fa-ellipsis-v"></i>',
						'fab_fa-ello'                      => '<i class="fab fa-ello"></i>',
						'fab_fa-ember'                     => '<i class="fab fa-ember"></i>',
						'fab_fa-empire'                    => '<i class="fab fa-empire"></i>',
						'fas_fa-envelope'                  => '<i class="fas fa-envelope"></i>',
						'fas_fa-envelope-open'             => '<i class="fas fa-envelope-open"></i>',
						'fas_fa-envelope-open-text'        => '<i class="fas fa-envelope-open-text"></i>',
						'fas_fa-envelope-square'           => '<i class="fas fa-envelope-square"></i>',
						'fab_fa-envira'                    => '<i class="fab fa-envira"></i>',
						'fas_fa-equals'                    => '<i class="fas fa-equals"></i>',
						'fas_fa-eraser'                    => '<i class="fas fa-eraser"></i>',
						'fab_fa-erlang'                    => '<i class="fab fa-erlang"></i>',
						'fab_fa-ethereum'                  => '<i class="fab fa-ethereum"></i>',
						'fas_fa-ethernet'                  => '<i class="fas fa-ethernet"></i>',
						'fab_fa-etsy'                      => '<i class="fab fa-etsy"></i>',
						'fas_fa-euro-sign'                 => '<i class="fas fa-euro-sign"></i>',
						'fas_fa-exchange-alt'              => '<i class="fas fa-exchange-alt"></i>',
						'fas_fa-exclamation'               => '<i class="fas fa-exclamation"></i>',
						'fas_fa-exclamation-circle'        => '<i class="fas fa-exclamation-circle"></i>',
						'fas_fa-exclamation-triangle'      => '<i class="fas fa-exclamation-triangle"></i>',
						'fas_fa-expand'                    => '<i class="fas fa-expand"></i>',
						'fas_fa-expand-arrows-alt'         => '<i class="fas fa-expand-arrows-alt"></i>',
						'fab_fa-expeditedssl'              => '<i class="fab fa-expeditedssl"></i>',
						'fas_fa-external-link-alt'         => '<i class="fas fa-external-link-alt"></i>',
						'fas_fa-external-link-square-alt'  => '<i class="fas fa-external-link-square-alt"></i>',
						'fas_fa-eye'                       => '<i class="fas fa-eye"></i>',
						'fas_fa-eye-dropper'               => '<i class="fas fa-eye-dropper"></i>',
						'fas_fa-eye-slash'                 => '<i class="fas fa-eye-slash"></i>',
						'fab_fa-facebook'                  => '<i class="fab fa-facebook"></i>',
						'fab_fa-facebook-f'                => '<i class="fab fa-facebook-f"></i>',
						'fab_fa-facebook-messenger'        => '<i class="fab fa-facebook-messenger"></i>',
						'fab_fa-facebook-square'           => '<i class="fab fa-facebook-square"></i>',
						'fab_fa-fantasy-flight-games'      => '<i class="fab fa-fantasy-flight-games"></i>',
						'fas_fa-fast-backward'             => '<i class="fas fa-fast-backward"></i>',
						'fas_fa-fast-forward'              => '<i class="fas fa-fast-forward"></i>',
						'fas_fa-fax'                       => '<i class="fas fa-fax"></i>',
						'fas_fa-feather'                   => '<i class="fas fa-feather"></i>',
						'fas_fa-feather-alt'               => '<i class="fas fa-feather-alt"></i>',
						'fab_fa-fedex'                     => '<i class="fab fa-fedex"></i>',
						'fab_fa-fedora'                    => '<i class="fab fa-fedora"></i>',
						'fas_fa-female'                    => '<i class="fas fa-female"></i>',
						'fas_fa-fighter-jet'               => '<i class="fas fa-fighter-jet"></i>',
						'fab_fa-figma'                     => '<i class="fab fa-figma"></i>',
						'fas_fa-file'                      => '<i class="fas fa-file"></i>',
						'fas_fa-file-alt'                  => '<i class="fas fa-file-alt"></i>',
						'fas_fa-file-archive'              => '<i class="fas fa-file-archive"></i>',
						'fas_fa-file-audio'                => '<i class="fas fa-file-audio"></i>',
						'fas_fa-file-code'                 => '<i class="fas fa-file-code"></i>',
						'fas_fa-file-contract'             => '<i class="fas fa-file-contract"></i>',
						'fas_fa-file-csv'                  => '<i class="fas fa-file-csv"></i>',
						'fas_fa-file-download'             => '<i class="fas fa-file-download"></i>',
						'fas_fa-file-excel'                => '<i class="fas fa-file-excel"></i>',
						'fas_fa-file-export'               => '<i class="fas fa-file-export"></i>',
						'fas_fa-file-image'                => '<i class="fas fa-file-image"></i>',
						'fas_fa-file-import'               => '<i class="fas fa-file-import"></i>',
						'fas_fa-file-invoice'              => '<i class="fas fa-file-invoice"></i>',
						'fas_fa-file-invoice-dollar'       => '<i class="fas fa-file-invoice-dollar"></i>',
						'fas_fa-file-medical'              => '<i class="fas fa-file-medical"></i>',
						'fas_fa-file-medical-alt'          => '<i class="fas fa-file-medical-alt"></i>',
						'fas_fa-file-pdf'                  => '<i class="fas fa-file-pdf"></i>',
						'fas_fa-file-powerpoint'           => '<i class="fas fa-file-powerpoint"></i>',
						'fas_fa-file-prescription'         => '<i class="fas fa-file-prescription"></i>',
						'fas_fa-file-signature'            => '<i class="fas fa-file-signature"></i>',
						'fas_fa-file-upload'               => '<i class="fas fa-file-upload"></i>',
						'fas_fa-file-video'                => '<i class="fas fa-file-video"></i>',
						'fas_fa-file-word'                 => '<i class="fas fa-file-word"></i>',
						'fas_fa-fill'                      => '<i class="fas fa-fill"></i>',
						'fas_fa-fill-drip'                 => '<i class="fas fa-fill-drip"></i>',
						'fas_fa-film'                      => '<i class="fas fa-film"></i>',
						'fas_fa-filter'                    => '<i class="fas fa-filter"></i>',
						'fas_fa-fingerprint'               => '<i class="fas fa-fingerprint"></i>',
						'fas_fa-fire'                      => '<i class="fas fa-fire"></i>',
						'fas_fa-fire-alt'                  => '<i class="fas fa-fire-alt"></i>',
						'fas_fa-fire-extinguisher'         => '<i class="fas fa-fire-extinguisher"></i>',
						'fab_fa-firefox'                   => '<i class="fab fa-firefox"></i>',
						'fas_fa-first-aid'                 => '<i class="fas fa-first-aid"></i>',
						'fab_fa-first-order'               => '<i class="fab fa-first-order"></i>',
						'fab_fa-first-order-alt'           => '<i class="fab fa-first-order-alt"></i>',
						'fab_fa-firstdraft'                => '<i class="fab fa-firstdraft"></i>',
						'fas_fa-fish'                      => '<i class="fas fa-fish"></i>',
						'fas_fa-fist-raised'               => '<i class="fas fa-fist-raised"></i>',
						'fas_fa-flag'                      => '<i class="fas fa-flag"></i>',
						'fas_fa-flag-checkered'            => '<i class="fas fa-flag-checkered"></i>',
						'fas_fa-flag-usa'                  => '<i class="fas fa-flag-usa"></i>',
						'fas_fa-flask'                     => '<i class="fas fa-flask"></i>',
						'fab_fa-flickr'                    => '<i class="fab fa-flickr"></i>',
						'fab_fa-flipboard'                 => '<i class="fab fa-flipboard"></i>',
						'fas_fa-flushed'                   => '<i class="fas fa-flushed"></i>',
						'fab_fa-fly'                       => '<i class="fab fa-fly"></i>',
						'fas_fa-folder'                    => '<i class="fas fa-folder"></i>',
						'fas_fa-folder-minus'              => '<i class="fas fa-folder-minus"></i>',
						'fas_fa-folder-open'               => '<i class="fas fa-folder-open"></i>',
						'fas_fa-folder-plus'               => '<i class="fas fa-folder-plus"></i>',
						'fas_fa-font'                      => '<i class="fas fa-font"></i>',
						'fab_fa-font-awesome'              => '<i class="fab fa-font-awesome"></i>',
						'fab_fa-font-awesome-alt'          => '<i class="fab fa-font-awesome-alt"></i>',
						'fab_fa-font-awesome-flag'         => '<i class="fab fa-font-awesome-flag"></i>',
						'fab_fa-fonticons'                 => '<i class="fab fa-fonticons"></i>',
						'fab_fa-fonticons-fi'              => '<i class="fab fa-fonticons-fi"></i>',
						'fas_fa-football-ball'             => '<i class="fas fa-football-ball"></i>',
						'fab_fa-fort-awesome'              => '<i class="fab fa-fort-awesome"></i>',
						'fab_fa-fort-awesome-alt'          => '<i class="fab fa-fort-awesome-alt"></i>',
						'fab_fa-forumbee'                  => '<i class="fab fa-forumbee"></i>',
						'fas_fa-forward'                   => '<i class="fas fa-forward"></i>',
						'fab_fa-foursquare'                => '<i class="fab fa-foursquare"></i>',
						'fab_fa-free-code-camp'            => '<i class="fab fa-free-code-camp"></i>',
						'fab_fa-freebsd'                   => '<i class="fab fa-freebsd"></i>',
						'fas_fa-frog'                      => '<i class="fas fa-frog"></i>',
						'fas_fa-frown'                     => '<i class="fas fa-frown"></i>',
						'fas_fa-frown-open'                => '<i class="fas fa-frown-open"></i>',
						'fab_fa-fulcrum'                   => '<i class="fab fa-fulcrum"></i>',
						'fas_fa-funnel-dollar'             => '<i class="fas fa-funnel-dollar"></i>',
						'fas_fa-futbol'                    => '<i class="fas fa-futbol"></i>',
						'fab_fa-galactic-republic'         => '<i class="fab fa-galactic-republic"></i>',
						'fab_fa-galactic-senate'           => '<i class="fab fa-galactic-senate"></i>',
						'fas_fa-gamepad'                   => '<i class="fas fa-gamepad"></i>',
						'fas_fa-gas-pump'                  => '<i class="fas fa-gas-pump"></i>',
						'fas_fa-gavel'                     => '<i class="fas fa-gavel"></i>',
						'fas_fa-gem'                       => '<i class="fas fa-gem"></i>',
						'fas_fa-genderless'                => '<i class="fas fa-genderless"></i>',
						'fab_fa-get-pocket'                => '<i class="fab fa-get-pocket"></i>',
						'fab_fa-gg'                        => '<i class="fab fa-gg"></i>',
						'fab_fa-gg-circle'                 => '<i class="fab fa-gg-circle"></i>',
						'fas_fa-ghost'                     => '<i class="fas fa-ghost"></i>',
						'fas_fa-gift'                      => '<i class="fas fa-gift"></i>',
						'fas_fa-gifts'                     => '<i class="fas fa-gifts"></i>',
						'fab_fa-git'                       => '<i class="fab fa-git"></i>',
						'fab_fa-git-square'                => '<i class="fab fa-git-square"></i>',
						'fab_fa-github'                    => '<i class="fab fa-github"></i>',
						'fab_fa-github-alt'                => '<i class="fab fa-github-alt"></i>',
						'fab_fa-github-square'             => '<i class="fab fa-github-square"></i>',
						'fab_fa-gitkraken'                 => '<i class="fab fa-gitkraken"></i>',
						'fab_fa-gitlab'                    => '<i class="fab fa-gitlab"></i>',
						'fab_fa-gitter'                    => '<i class="fab fa-gitter"></i>',
						'fas_fa-glass-cheers'              => '<i class="fas fa-glass-cheers"></i>',
						'fas_fa-glass-martini'             => '<i class="fas fa-glass-martini"></i>',
						'fas_fa-glass-martini-alt'         => '<i class="fas fa-glass-martini-alt"></i>',
						'fas_fa-glass-whiskey'             => '<i class="fas fa-glass-whiskey"></i>',
						'fas_fa-glasses'                   => '<i class="fas fa-glasses"></i>',
						'fab_fa-glide'                     => '<i class="fab fa-glide"></i>',
						'fab_fa-glide-g'                   => '<i class="fab fa-glide-g"></i>',
						'fas_fa-globe'                     => '<i class="fas fa-globe"></i>',
						'fas_fa-globe-africa'              => '<i class="fas fa-globe-africa"></i>',
						'fas_fa-globe-americas'            => '<i class="fas fa-globe-americas"></i>',
						'fas_fa-globe-asia'                => '<i class="fas fa-globe-asia"></i>',
						'fas_fa-globe-europe'              => '<i class="fas fa-globe-europe"></i>',
						'fab_fa-gofore'                    => '<i class="fab fa-gofore"></i>',
						'fas_fa-golf-ball'                 => '<i class="fas fa-golf-ball"></i>',
						'fab_fa-goodreads'                 => '<i class="fab fa-goodreads"></i>',
						'fab_fa-goodreads-g'               => '<i class="fab fa-goodreads-g"></i>',
						'fab_fa-google'                    => '<i class="fab fa-google"></i>',
						'fab_fa-google-drive'              => '<i class="fab fa-google-drive"></i>',
						'fab_fa-google-play'               => '<i class="fab fa-google-play"></i>',
						'fab_fa-google-plus'               => '<i class="fab fa-google-plus"></i>',
						'fab_fa-google-plus-g'             => '<i class="fab fa-google-plus-g"></i>',
						'fab_fa-google-plus-square'        => '<i class="fab fa-google-plus-square"></i>',
						'fab_fa-google-wallet'             => '<i class="fab fa-google-wallet"></i>',
						'fas_fa-gopuram'                   => '<i class="fas fa-gopuram"></i>',
						'fas_fa-graduation-cap'            => '<i class="fas fa-graduation-cap"></i>',
						'fab_fa-gratipay'                  => '<i class="fab fa-gratipay"></i>',
						'fab_fa-grav'                      => '<i class="fab fa-grav"></i>',
						'fas_fa-greater-than'              => '<i class="fas fa-greater-than"></i>',
						'fas_fa-greater-than-equal'        => '<i class="fas fa-greater-than-equal"></i>',
						'fas_fa-grimace'                   => '<i class="fas fa-grimace"></i>',
						'fas_fa-grin'                      => '<i class="fas fa-grin"></i>',
						'fas_fa-grin-alt'                  => '<i class="fas fa-grin-alt"></i>',
						'fas_fa-grin-beam'                 => '<i class="fas fa-grin-beam"></i>',
						'fas_fa-grin-beam-sweat'           => '<i class="fas fa-grin-beam-sweat"></i>',
						'fas_fa-grin-hearts'               => '<i class="fas fa-grin-hearts"></i>',
						'fas_fa-grin-squint'               => '<i class="fas fa-grin-squint"></i>',
						'fas_fa-grin-squint-tears'         => '<i class="fas fa-grin-squint-tears"></i>',
						'fas_fa-grin-stars'                => '<i class="fas fa-grin-stars"></i>',
						'fas_fa-grin-tears'                => '<i class="fas fa-grin-tears"></i>',
						'fas_fa-grin-tongue'               => '<i class="fas fa-grin-tongue"></i>',
						'fas_fa-grin-tongue-squint'        => '<i class="fas fa-grin-tongue-squint"></i>',
						'fas_fa-grin-tongue-wink'          => '<i class="fas fa-grin-tongue-wink"></i>',
						'fas_fa-grin-wink'                 => '<i class="fas fa-grin-wink"></i>',
						'fas_fa-grip-horizontal'           => '<i class="fas fa-grip-horizontal"></i>',
						'fas_fa-grip-lines'                => '<i class="fas fa-grip-lines"></i>',
						'fas_fa-grip-lines-vertical'       => '<i class="fas fa-grip-lines-vertical"></i>',
						'fas_fa-grip-vertical'             => '<i class="fas fa-grip-vertical"></i>',
						'fab_fa-gripfire'                  => '<i class="fab fa-gripfire"></i>',
						'fab_fa-grunt'                     => '<i class="fab fa-grunt"></i>',
						'fas_fa-guitar'                    => '<i class="fas fa-guitar"></i>',
						'fab_fa-gulp'                      => '<i class="fab fa-gulp"></i>',
						'fas_fa-h-square'                  => '<i class="fas fa-h-square"></i>',
						'fab_fa-hacker-news'               => '<i class="fab fa-hacker-news"></i>',
						'fab_fa-hacker-news-square'        => '<i class="fab fa-hacker-news-square"></i>',
						'fab_fa-hackerrank'                => '<i class="fab fa-hackerrank"></i>',
						'fas_fa-hamburger'                 => '<i class="fas fa-hamburger"></i>',
						'fas_fa-hammer'                    => '<i class="fas fa-hammer"></i>',
						'fas_fa-hamsa'                     => '<i class="fas fa-hamsa"></i>',
						'fas_fa-hand-holding'              => '<i class="fas fa-hand-holding"></i>',
						'fas_fa-hand-holding-heart'        => '<i class="fas fa-hand-holding-heart"></i>',
						'fas_fa-hand-holding-usd'          => '<i class="fas fa-hand-holding-usd"></i>',
						'fas_fa-hand-lizard'               => '<i class="fas fa-hand-lizard"></i>',
						'fas_fa-hand-middle-finger'        => '<i class="fas fa-hand-middle-finger"></i>',
						'fas_fa-hand-paper'                => '<i class="fas fa-hand-paper"></i>',
						'fas_fa-hand-peace'                => '<i class="fas fa-hand-peace"></i>',
						'fas_fa-hand-point-down'           => '<i class="fas fa-hand-point-down"></i>',
						'fas_fa-hand-point-left'           => '<i class="fas fa-hand-point-left"></i>',
						'fas_fa-hand-point-right'          => '<i class="fas fa-hand-point-right"></i>',
						'fas_fa-hand-point-up'             => '<i class="fas fa-hand-point-up"></i>',
						'fas_fa-hand-pointer'              => '<i class="fas fa-hand-pointer"></i>',
						'fas_fa-hand-rock'                 => '<i class="fas fa-hand-rock"></i>',
						'fas_fa-hand-scissors'             => '<i class="fas fa-hand-scissors"></i>',
						'fas_fa-hand-spock'                => '<i class="fas fa-hand-spock"></i>',
						'fas_fa-hands'                     => '<i class="fas fa-hands"></i>',
						'fas_fa-hands-helping'             => '<i class="fas fa-hands-helping"></i>',
						'fas_fa-handshake'                 => '<i class="fas fa-handshake"></i>',
						'fas_fa-hanukiah'                  => '<i class="fas fa-hanukiah"></i>',
						'fas_fa-hard-hat'                  => '<i class="fas fa-hard-hat"></i>',
						'fas_fa-hashtag'                   => '<i class="fas fa-hashtag"></i>',
						'fas_fa-hat-wizard'                => '<i class="fas fa-hat-wizard"></i>',
						'fas_fa-haykal'                    => '<i class="fas fa-haykal"></i>',
						'fas_fa-hdd'                       => '<i class="fas fa-hdd"></i>',
						'fas_fa-heading'                   => '<i class="fas fa-heading"></i>',
						'fas_fa-headphones'                => '<i class="fas fa-headphones"></i>',
						'fas_fa-headphones-alt'            => '<i class="fas fa-headphones-alt"></i>',
						'fas_fa-headset'                   => '<i class="fas fa-headset"></i>',
						'fas_fa-heart'                     => '<i class="fas fa-heart"></i>',
						'fas_fa-heart-broken'              => '<i class="fas fa-heart-broken"></i>',
						'fas_fa-heartbeat'                 => '<i class="fas fa-heartbeat"></i>',
						'fas_fa-helicopter'                => '<i class="fas fa-helicopter"></i>',
						'fas_fa-highlighter'               => '<i class="fas fa-highlighter"></i>',
						'fas_fa-hiking'                    => '<i class="fas fa-hiking"></i>',
						'fas_fa-hippo'                     => '<i class="fas fa-hippo"></i>',
						'fab_fa-hips'                      => '<i class="fab fa-hips"></i>',
						'fab_fa-hire-a-helper'             => '<i class="fab fa-hire-a-helper"></i>',
						'fas_fa-history'                   => '<i class="fas fa-history"></i>',
						'fas_fa-hockey-puck'               => '<i class="fas fa-hockey-puck"></i>',
						'fas_fa-holly-berry'               => '<i class="fas fa-holly-berry"></i>',
						'fas_fa-home'                      => '<i class="fas fa-home"></i>',
						'fab_fa-hooli'                     => '<i class="fab fa-hooli"></i>',
						'fab_fa-hornbill'                  => '<i class="fab fa-hornbill"></i>',
						'fas_fa-horse'                     => '<i class="fas fa-horse"></i>',
						'fas_fa-horse-head'                => '<i class="fas fa-horse-head"></i>',
						'fas_fa-hospital'                  => '<i class="fas fa-hospital"></i>',
						'fas_fa-hospital-alt'              => '<i class="fas fa-hospital-alt"></i>',
						'fas_fa-hospital-symbol'           => '<i class="fas fa-hospital-symbol"></i>',
						'fas_fa-hot-tub'                   => '<i class="fas fa-hot-tub"></i>',
						'fas_fa-hotdog'                    => '<i class="fas fa-hotdog"></i>',
						'fas_fa-hotel'                     => '<i class="fas fa-hotel"></i>',
						'fab_fa-hotjar'                    => '<i class="fab fa-hotjar"></i>',
						'fas_fa-hourglass'                 => '<i class="fas fa-hourglass"></i>',
						'fas_fa-hourglass-end'             => '<i class="fas fa-hourglass-end"></i>',
						'fas_fa-hourglass-half'            => '<i class="fas fa-hourglass-half"></i>',
						'fas_fa-hourglass-start'           => '<i class="fas fa-hourglass-start"></i>',
						'fas_fa-house-damage'              => '<i class="fas fa-house-damage"></i>',
						'fab_fa-houzz'                     => '<i class="fab fa-houzz"></i>',
						'fas_fa-hryvnia'                   => '<i class="fas fa-hryvnia"></i>',
						'fab_fa-html'                      => '<i class="fab fa-html"></i>',
						'fab_fa-hubspot'                   => '<i class="fab fa-hubspot"></i>',
						'fas_fa-i-cursor'                  => '<i class="fas fa-i-cursor"></i>',
						'fas_fa-ice-cream'                 => '<i class="fas fa-ice-cream"></i>',
						'fas_fa-icicles'                   => '<i class="fas fa-icicles"></i>',
						'fas_fa-id-badge'                  => '<i class="fas fa-id-badge"></i>',
						'fas_fa-id-card'                   => '<i class="fas fa-id-card"></i>',
						'fas_fa-id-card-alt'               => '<i class="fas fa-id-card-alt"></i>',
						'fas_fa-igloo'                     => '<i class="fas fa-igloo"></i>',
						'fas_fa-image'                     => '<i class="fas fa-image"></i>',
						'fas_fa-images'                    => '<i class="fas fa-images"></i>',
						'fab_fa-imdb'                      => '<i class="fab fa-imdb"></i>',
						'fas_fa-inbox'                     => '<i class="fas fa-inbox"></i>',
						'fas_fa-indent'                    => '<i class="fas fa-indent"></i>',
						'fas_fa-industry'                  => '<i class="fas fa-industry"></i>',
						'fas_fa-infinity'                  => '<i class="fas fa-infinity"></i>',
						'fas_fa-info'                      => '<i class="fas fa-info"></i>',
						'fas_fa-info-circle'               => '<i class="fas fa-info-circle"></i>',
						'fab_fa-instagram'                 => '<i class="fab fa-instagram"></i>',
						'fab_fa-intercom'                  => '<i class="fab fa-intercom"></i>',
						'fab_fa-internet-explorer'         => '<i class="fab fa-internet-explorer"></i>',
						'fab_fa-invision'                  => '<i class="fab fa-invision"></i>',
						'fab_fa-ioxhost'                   => '<i class="fab fa-ioxhost"></i>',
						'fas_fa-italic'                    => '<i class="fas fa-italic"></i>',
						'fab_fa-itunes'                    => '<i class="fab fa-itunes"></i>',
						'fab_fa-itunes-note'               => '<i class="fab fa-itunes-note"></i>',
						'fab_fa-java'                      => '<i class="fab fa-java"></i>',
						'fas_fa-jedi'                      => '<i class="fas fa-jedi"></i>',
						'fab_fa-jedi-order'                => '<i class="fab fa-jedi-order"></i>',
						'fab_fa-jenkins'                   => '<i class="fab fa-jenkins"></i>',
						'fab_fa-jira'                      => '<i class="fab fa-jira"></i>',
						'fab_fa-joget'                     => '<i class="fab fa-joget"></i>',
						'fas_fa-joint'                     => '<i class="fas fa-joint"></i>',
						'fab_fa-joomla'                    => '<i class="fab fa-joomla"></i>',
						'fas_fa-journal-whills'            => '<i class="fas fa-journal-whills"></i>',
						'fab_fa-js'                        => '<i class="fab fa-js"></i>',
						'fab_fa-js-square'                 => '<i class="fab fa-js-square"></i>',
						'fab_fa-jsfiddle'                  => '<i class="fab fa-jsfiddle"></i>',
						'fas_fa-kaaba'                     => '<i class="fas fa-kaaba"></i>',
						'fab_fa-kaggle'                    => '<i class="fab fa-kaggle"></i>',
						'fas_fa-key'                       => '<i class="fas fa-key"></i>',
						'fab_fa-keybase'                   => '<i class="fab fa-keybase"></i>',
						'fas_fa-keyboard'                  => '<i class="fas fa-keyboard"></i>',
						'fab_fa-keycdn'                    => '<i class="fab fa-keycdn"></i>',
						'fas_fa-khanda'                    => '<i class="fas fa-khanda"></i>',
						'fab_fa-kickstarter'               => '<i class="fab fa-kickstarter"></i>',
						'fab_fa-kickstarter-k'             => '<i class="fab fa-kickstarter-k"></i>',
						'fas_fa-kiss'                      => '<i class="fas fa-kiss"></i>',
						'fas_fa-kiss-beam'                 => '<i class="fas fa-kiss-beam"></i>',
						'fas_fa-kiss-wink-heart'           => '<i class="fas fa-kiss-wink-heart"></i>',
						'fas_fa-kiwi-bird'                 => '<i class="fas fa-kiwi-bird"></i>',
						'fab_fa-korvue'                    => '<i class="fab fa-korvue"></i>',
						'fas_fa-landmark'                  => '<i class="fas fa-landmark"></i>',
						'fas_fa-language'                  => '<i class="fas fa-language"></i>',
						'fas_fa-laptop'                    => '<i class="fas fa-laptop"></i>',
						'fas_fa-laptop-code'               => '<i class="fas fa-laptop-code"></i>',
						'fas_fa-laptop-medical'            => '<i class="fas fa-laptop-medical"></i>',
						'fab_fa-laravel'                   => '<i class="fab fa-laravel"></i>',
						'fab_fa-lastfm'                    => '<i class="fab fa-lastfm"></i>',
						'fab_fa-lastfm-square'             => '<i class="fab fa-lastfm-square"></i>',
						'fas_fa-laugh'                     => '<i class="fas fa-laugh"></i>',
						'fas_fa-laugh-beam'                => '<i class="fas fa-laugh-beam"></i>',
						'fas_fa-laugh-squint'              => '<i class="fas fa-laugh-squint"></i>',
						'fas_fa-laugh-wink'                => '<i class="fas fa-laugh-wink"></i>',
						'fas_fa-layer-group'               => '<i class="fas fa-layer-group"></i>',
						'fas_fa-leaf'                      => '<i class="fas fa-leaf"></i>',
						'fab_fa-leanpub'                   => '<i class="fab fa-leanpub"></i>',
						'fas_fa-lemon'                     => '<i class="fas fa-lemon"></i>',
						'fab_fa-less'                      => '<i class="fab fa-less"></i>',
						'fas_fa-less-than'                 => '<i class="fas fa-less-than"></i>',
						'fas_fa-less-than-equal'           => '<i class="fas fa-less-than-equal"></i>',
						'fas_fa-level-down-alt'            => '<i class="fas fa-level-down-alt"></i>',
						'fas_fa-level-up-alt'              => '<i class="fas fa-level-up-alt"></i>',
						'fas_fa-life-ring'                 => '<i class="fas fa-life-ring"></i>',
						'fas_fa-lightbulb'                 => '<i class="fas fa-lightbulb"></i>',
						'fab_fa-line'                      => '<i class="fab fa-line"></i>',
						'fas_fa-link'                      => '<i class="fas fa-link"></i>',
						'fab_fa-linkedin'                  => '<i class="fab fa-linkedin"></i>',
						'fab_fa-linkedin-in'               => '<i class="fab fa-linkedin-in"></i>',
						'fab_fa-linode'                    => '<i class="fab fa-linode"></i>',
						'fab_fa-linux'                     => '<i class="fab fa-linux"></i>',
						'fas_fa-lira-sign'                 => '<i class="fas fa-lira-sign"></i>',
						'fas_fa-list'                      => '<i class="fas fa-list"></i>',
						'fas_fa-list-alt'                  => '<i class="fas fa-list-alt"></i>',
						'fas_fa-list-ol'                   => '<i class="fas fa-list-ol"></i>',
						'fas_fa-list-ul'                   => '<i class="fas fa-list-ul"></i>',
						'fas_fa-location-arrow'            => '<i class="fas fa-location-arrow"></i>',
						'fas_fa-lock'                      => '<i class="fas fa-lock"></i>',
						'fas_fa-lock-open'                 => '<i class="fas fa-lock-open"></i>',
						'fas_fa-long-arrow-alt-down'       => '<i class="fas fa-long-arrow-alt-down"></i>',
						'fas_fa-long-arrow-alt-left'       => '<i class="fas fa-long-arrow-alt-left"></i>',
						'fas_fa-long-arrow-alt-right'      => '<i class="fas fa-long-arrow-alt-right"></i>',
						'fas_fa-long-arrow-alt-up'         => '<i class="fas fa-long-arrow-alt-up"></i>',
						'fas_fa-low-vision'                => '<i class="fas fa-low-vision"></i>',
						'fas_fa-luggage-cart'              => '<i class="fas fa-luggage-cart"></i>',
						'fab_fa-lyft'                      => '<i class="fab fa-lyft"></i>',
						'fab_fa-magento'                   => '<i class="fab fa-magento"></i>',
						'fas_fa-magic'                     => '<i class="fas fa-magic"></i>',
						'fas_fa-magnet'                    => '<i class="fas fa-magnet"></i>',
						'fas_fa-mail-bulk'                 => '<i class="fas fa-mail-bulk"></i>',
						'fab_fa-mailchimp'                 => '<i class="fab fa-mailchimp"></i>',
						'fas_fa-male'                      => '<i class="fas fa-male"></i>',
						'fab_fa-mandalorian'               => '<i class="fab fa-mandalorian"></i>',
						'fas_fa-map'                       => '<i class="fas fa-map"></i>',
						'fas_fa-map-marked'                => '<i class="fas fa-map-marked"></i>',
						'fas_fa-map-marked-alt'            => '<i class="fas fa-map-marked-alt"></i>',
						'fas_fa-map-marker'                => '<i class="fas fa-map-marker"></i>',
						'fas_fa-map-marker-alt'            => '<i class="fas fa-map-marker-alt"></i>',
						'fas_fa-map-pin'                   => '<i class="fas fa-map-pin"></i>',
						'fas_fa-map-signs'                 => '<i class="fas fa-map-signs"></i>',
						'fab_fa-markdown'                  => '<i class="fab fa-markdown"></i>',
						'fas_fa-marker'                    => '<i class="fas fa-marker"></i>',
						'fas_fa-mars'                      => '<i class="fas fa-mars"></i>',
						'fas_fa-mars-double'               => '<i class="fas fa-mars-double"></i>',
						'fas_fa-mars-stroke'               => '<i class="fas fa-mars-stroke"></i>',
						'fas_fa-mars-stroke-h'             => '<i class="fas fa-mars-stroke-h"></i>',
						'fas_fa-mars-stroke-v'             => '<i class="fas fa-mars-stroke-v"></i>',
						'fas_fa-mask'                      => '<i class="fas fa-mask"></i>',
						'fab_fa-mastodon'                  => '<i class="fab fa-mastodon"></i>',
						'fab_fa-maxcdn'                    => '<i class="fab fa-maxcdn"></i>',
						'fas_fa-medal'                     => '<i class="fas fa-medal"></i>',
						'fab_fa-medapps'                   => '<i class="fab fa-medapps"></i>',
						'fab_fa-medium'                    => '<i class="fab fa-medium"></i>',
						'fab_fa-medium-m'                  => '<i class="fab fa-medium-m"></i>',
						'fas_fa-medkit'                    => '<i class="fas fa-medkit"></i>',
						'fab_fa-medrt'                     => '<i class="fab fa-medrt"></i>',
						'fab_fa-meetup'                    => '<i class="fab fa-meetup"></i>',
						'fab_fa-megaport'                  => '<i class="fab fa-megaport"></i>',
						'fas_fa-meh'                       => '<i class="fas fa-meh"></i>',
						'fas_fa-meh-blank'                 => '<i class="fas fa-meh-blank"></i>',
						'fas_fa-meh-rolling-eyes'          => '<i class="fas fa-meh-rolling-eyes"></i>',
						'fas_fa-memory'                    => '<i class="fas fa-memory"></i>',
						'fab_fa-mendeley'                  => '<i class="fab fa-mendeley"></i>',
						'fas_fa-menorah'                   => '<i class="fas fa-menorah"></i>',
						'fas_fa-mercury'                   => '<i class="fas fa-mercury"></i>',
						'fas_fa-meteor'                    => '<i class="fas fa-meteor"></i>',
						'fas_fa-microchip'                 => '<i class="fas fa-microchip"></i>',
						'fas_fa-microphone'                => '<i class="fas fa-microphone"></i>',
						'fas_fa-microphone-alt'            => '<i class="fas fa-microphone-alt"></i>',
						'fas_fa-microphone-alt-slash'      => '<i class="fas fa-microphone-alt-slash"></i>',
						'fas_fa-microphone-slash'          => '<i class="fas fa-microphone-slash"></i>',
						'fas_fa-microscope'                => '<i class="fas fa-microscope"></i>',
						'fab_fa-microsoft'                 => '<i class="fab fa-microsoft"></i>',
						'fas_fa-minus'                     => '<i class="fas fa-minus"></i>',
						'fas_fa-minus-circle'              => '<i class="fas fa-minus-circle"></i>',
						'fas_fa-minus-square'              => '<i class="fas fa-minus-square"></i>',
						'fas_fa-mitten'                    => '<i class="fas fa-mitten"></i>',
						'fab_fa-mix'                       => '<i class="fab fa-mix"></i>',
						'fab_fa-mixcloud'                  => '<i class="fab fa-mixcloud"></i>',
						'fab_fa-mizuni'                    => '<i class="fab fa-mizuni"></i>',
						'fas_fa-mobile'                    => '<i class="fas fa-mobile"></i>',
						'fas_fa-mobile-alt'                => '<i class="fas fa-mobile-alt"></i>',
						'fab_fa-modx'                      => '<i class="fab fa-modx"></i>',
						'fab_fa-monero'                    => '<i class="fab fa-monero"></i>',
						'fas_fa-money-bill'                => '<i class="fas fa-money-bill"></i>',
						'fas_fa-money-bill-alt'            => '<i class="fas fa-money-bill-alt"></i>',
						'fas_fa-money-bill-wave'           => '<i class="fas fa-money-bill-wave"></i>',
						'fas_fa-money-bill-wave-alt'       => '<i class="fas fa-money-bill-wave-alt"></i>',
						'fas_fa-money-check'               => '<i class="fas fa-money-check"></i>',
						'fas_fa-money-check-alt'           => '<i class="fas fa-money-check-alt"></i>',
						'fas_fa-monument'                  => '<i class="fas fa-monument"></i>',
						'fas_fa-moon'                      => '<i class="fas fa-moon"></i>',
						'fas_fa-mortar-pestle'             => '<i class="fas fa-mortar-pestle"></i>',
						'fas_fa-mosque'                    => '<i class="fas fa-mosque"></i>',
						'fas_fa-motorcycle'                => '<i class="fas fa-motorcycle"></i>',
						'fas_fa-mountain'                  => '<i class="fas fa-mountain"></i>',
						'fas_fa-mouse-pointer'             => '<i class="fas fa-mouse-pointer"></i>',
						'fas_fa-mug-hot'                   => '<i class="fas fa-mug-hot"></i>',
						'fas_fa-music'                     => '<i class="fas fa-music"></i>',
						'fab_fa-neos'                      => '<i class="fab fa-neos"></i>',
						'fas_fa-network-wired'             => '<i class="fas fa-network-wired"></i>',
						'fas_fa-neuter'                    => '<i class="fas fa-neuter"></i>',
						'fas_fa-newspaper'                 => '<i class="fas fa-newspaper"></i>',
						'fab_fa-nimblr'                    => '<i class="fab fa-nimblr"></i>',
						'fab_fa-nintendo-switch'           => '<i class="fab fa-nintendo-switch"></i>',
						'fab_fa-node'                      => '<i class="fab fa-node"></i>',
						'fab_fa-node-js'                   => '<i class="fab fa-node-js"></i>',
						'fas_fa-not-equal'                 => '<i class="fas fa-not-equal"></i>',
						'fas_fa-notes-medical'             => '<i class="fas fa-notes-medical"></i>',
						'fab_fa-npm'                       => '<i class="fab fa-npm"></i>',
						'fab_fa-ns'                        => '<i class="fab fa-ns"></i>',
						'fab_fa-nutritionix'               => '<i class="fab fa-nutritionix"></i>',
						'fas_fa-object-group'              => '<i class="fas fa-object-group"></i>',
						'fas_fa-object-ungroup'            => '<i class="fas fa-object-ungroup"></i>',
						'fab_fa-odnoklassniki'             => '<i class="fab fa-odnoklassniki"></i>',
						'fab_fa-odnoklassniki-square'      => '<i class="fab fa-odnoklassniki-square"></i>',
						'fas_fa-oil-can'                   => '<i class="fas fa-oil-can"></i>',
						'fab_fa-old-republic'              => '<i class="fab fa-old-republic"></i>',
						'fas_fa-om'                        => '<i class="fas fa-om"></i>',
						'fab_fa-opencart'                  => '<i class="fab fa-opencart"></i>',
						'fab_fa-openid'                    => '<i class="fab fa-openid"></i>',
						'fab_fa-opera'                     => '<i class="fab fa-opera"></i>',
						'fab_fa-optin-monster'             => '<i class="fab fa-optin-monster"></i>',
						'fab_fa-osi'                       => '<i class="fab fa-osi"></i>',
						'fas_fa-otter'                     => '<i class="fas fa-otter"></i>',
						'fas_fa-outdent'                   => '<i class="fas fa-outdent"></i>',
						'fab_fa-page'                      => '<i class="fab fa-page"></i>',
						'fab_fa-pagelines'                 => '<i class="fab fa-pagelines"></i>',
						'fas_fa-pager'                     => '<i class="fas fa-pager"></i>',
						'fas_fa-paint-brush'               => '<i class="fas fa-paint-brush"></i>',
						'fas_fa-paint-roller'              => '<i class="fas fa-paint-roller"></i>',
						'fas_fa-palette'                   => '<i class="fas fa-palette"></i>',
						'fab_fa-palfed'                    => '<i class="fab fa-palfed"></i>',
						'fas_fa-pallet'                    => '<i class="fas fa-pallet"></i>',
						'fas_fa-paper-plane'               => '<i class="fas fa-paper-plane"></i>',
						'fas_fa-paperclip'                 => '<i class="fas fa-paperclip"></i>',
						'fas_fa-parachute-box'             => '<i class="fas fa-parachute-box"></i>',
						'fas_fa-paragraph'                 => '<i class="fas fa-paragraph"></i>',
						'fas_fa-parking'                   => '<i class="fas fa-parking"></i>',
						'fas_fa-passport'                  => '<i class="fas fa-passport"></i>',
						'fas_fa-pastafarianism'            => '<i class="fas fa-pastafarianism"></i>',
						'fas_fa-paste'                     => '<i class="fas fa-paste"></i>',
						'fab_fa-patreon'                   => '<i class="fab fa-patreon"></i>',
						'fas_fa-pause'                     => '<i class="fas fa-pause"></i>',
						'fas_fa-pause-circle'              => '<i class="fas fa-pause-circle"></i>',
						'fas_fa-paw'                       => '<i class="fas fa-paw"></i>',
						'fab_fa-paypal'                    => '<i class="fab fa-paypal"></i>',
						'fas_fa-peace'                     => '<i class="fas fa-peace"></i>',
						'fas_fa-pen'                       => '<i class="fas fa-pen"></i>',
						'fas_fa-pen-alt'                   => '<i class="fas fa-pen-alt"></i>',
						'fas_fa-pen-fancy'                 => '<i class="fas fa-pen-fancy"></i>',
						'fas_fa-pen-nib'                   => '<i class="fas fa-pen-nib"></i>',
						'fas_fa-pen-square'                => '<i class="fas fa-pen-square"></i>',
						'fas_fa-pencil-alt'                => '<i class="fas fa-pencil-alt"></i>',
						'fas_fa-pencil-ruler'              => '<i class="fas fa-pencil-ruler"></i>',
						'fab_fa-penny-arcade'              => '<i class="fab fa-penny-arcade"></i>',
						'fas_fa-people-carry'              => '<i class="fas fa-people-carry"></i>',
						'fas_fa-pepper-hot'                => '<i class="fas fa-pepper-hot"></i>',
						'fas_fa-percent'                   => '<i class="fas fa-percent"></i>',
						'fas_fa-percentage'                => '<i class="fas fa-percentage"></i>',
						'fab_fa-periscope'                 => '<i class="fab fa-periscope"></i>',
						'fas_fa-person-booth'              => '<i class="fas fa-person-booth"></i>',
						'fab_fa-phabricator'               => '<i class="fab fa-phabricator"></i>',
						'fab_fa-phoenix-framework'         => '<i class="fab fa-phoenix-framework"></i>',
						'fab_fa-phoenix-squadron'          => '<i class="fab fa-phoenix-squadron"></i>',
						'fas_fa-phone'                     => '<i class="fas fa-phone"></i>',
						'fas_fa-phone-slash'               => '<i class="fas fa-phone-slash"></i>',
						'fas_fa-phone-square'              => '<i class="fas fa-phone-square"></i>',
						'fas_fa-phone-volume'              => '<i class="fas fa-phone-volume"></i>',
						'fab_fa-php'                       => '<i class="fab fa-php"></i>',
						'fab_fa-pied-piper'                => '<i class="fab fa-pied-piper"></i>',
						'fab_fa-pied-piper-alt'            => '<i class="fab fa-pied-piper-alt"></i>',
						'fab_fa-pied-piper-hat'            => '<i class="fab fa-pied-piper-hat"></i>',
						'fab_fa-pied-piper-pp'             => '<i class="fab fa-pied-piper-pp"></i>',
						'fas_fa-piggy-bank'                => '<i class="fas fa-piggy-bank"></i>',
						'fas_fa-pills'                     => '<i class="fas fa-pills"></i>',
						'fab_fa-pinterest'                 => '<i class="fab fa-pinterest"></i>',
						'fab_fa-pinterest-p'               => '<i class="fab fa-pinterest-p"></i>',
						'fab_fa-pinterest-square'          => '<i class="fab fa-pinterest-square"></i>',
						'fas_fa-pizza-slice'               => '<i class="fas fa-pizza-slice"></i>',
						'fas_fa-place-of-worship'          => '<i class="fas fa-place-of-worship"></i>',
						'fas_fa-plane'                     => '<i class="fas fa-plane"></i>',
						'fas_fa-plane-arrival'             => '<i class="fas fa-plane-arrival"></i>',
						'fas_fa-plane-departure'           => '<i class="fas fa-plane-departure"></i>',
						'fas_fa-play'                      => '<i class="fas fa-play"></i>',
						'fas_fa-play-circle'               => '<i class="fas fa-play-circle"></i>',
						'fab_fa-playstation'               => '<i class="fab fa-playstation"></i>',
						'fas_fa-plug'                      => '<i class="fas fa-plug"></i>',
						'fas_fa-plus'                      => '<i class="fas fa-plus"></i>',
						'fas_fa-plus-circle'               => '<i class="fas fa-plus-circle"></i>',
						'fas_fa-plus-square'               => '<i class="fas fa-plus-square"></i>',
						'fas_fa-podcast'                   => '<i class="fas fa-podcast"></i>',
						'fas_fa-poll'                      => '<i class="fas fa-poll"></i>',
						'fas_fa-poll-h'                    => '<i class="fas fa-poll-h"></i>',
						'fas_fa-poo'                       => '<i class="fas fa-poo"></i>',
						'fas_fa-poo-storm'                 => '<i class="fas fa-poo-storm"></i>',
						'fas_fa-poop'                      => '<i class="fas fa-poop"></i>',
						'fas_fa-portrait'                  => '<i class="fas fa-portrait"></i>',
						'fas_fa-pound-sign'                => '<i class="fas fa-pound-sign"></i>',
						'fas_fa-power-off'                 => '<i class="fas fa-power-off"></i>',
						'fas_fa-pray'                      => '<i class="fas fa-pray"></i>',
						'fas_fa-praying-hands'             => '<i class="fas fa-praying-hands"></i>',
						'fas_fa-prescription'              => '<i class="fas fa-prescription"></i>',
						'fas_fa-prescription-bottle'       => '<i class="fas fa-prescription-bottle"></i>',
						'fas_fa-prescription-bottle-alt'   => '<i class="fas fa-prescription-bottle-alt"></i>',
						'fas_fa-print'                     => '<i class="fas fa-print"></i>',
						'fas_fa-procedures'                => '<i class="fas fa-procedures"></i>',
						'fab_fa-product-hunt'              => '<i class="fab fa-product-hunt"></i>',
						'fas_fa-project-diagram'           => '<i class="fas fa-project-diagram"></i>',
						'fab_fa-pushed'                    => '<i class="fab fa-pushed"></i>',
						'fas_fa-puzzle-piece'              => '<i class="fas fa-puzzle-piece"></i>',
						'fab_fa-python'                    => '<i class="fab fa-python"></i>',
						'fab_fa-qq'                        => '<i class="fab fa-qq"></i>',
						'fas_fa-qrcode'                    => '<i class="fas fa-qrcode"></i>',
						'fas_fa-question'                  => '<i class="fas fa-question"></i>',
						'fas_fa-question-circle'           => '<i class="fas fa-question-circle"></i>',
						'fas_fa-quidditch'                 => '<i class="fas fa-quidditch"></i>',
						'fab_fa-quinscape'                 => '<i class="fab fa-quinscape"></i>',
						'fab_fa-quora'                     => '<i class="fab fa-quora"></i>',
						'fas_fa-quote-left'                => '<i class="fas fa-quote-left"></i>',
						'fas_fa-quote-right'               => '<i class="fas fa-quote-right"></i>',
						'fas_fa-quran'                     => '<i class="fas fa-quran"></i>',
						'fab_fa-r-project'                 => '<i class="fab fa-r-project"></i>',
						'fas_fa-radiation'                 => '<i class="fas fa-radiation"></i>',
						'fas_fa-radiation-alt'             => '<i class="fas fa-radiation-alt"></i>',
						'fas_fa-rainbow'                   => '<i class="fas fa-rainbow"></i>',
						'fas_fa-random'                    => '<i class="fas fa-random"></i>',
						'fab_fa-raspberry-pi'              => '<i class="fab fa-raspberry-pi"></i>',
						'fab_fa-ravelry'                   => '<i class="fab fa-ravelry"></i>',
						'fab_fa-react'                     => '<i class="fab fa-react"></i>',
						'fab_fa-reacteurope'               => '<i class="fab fa-reacteurope"></i>',
						'fab_fa-readme'                    => '<i class="fab fa-readme"></i>',
						'fab_fa-rebel'                     => '<i class="fab fa-rebel"></i>',
						'fas_fa-receipt'                   => '<i class="fas fa-receipt"></i>',
						'fas_fa-recycle'                   => '<i class="fas fa-recycle"></i>',
						'fab_fa-red-river'                 => '<i class="fab fa-red-river"></i>',
						'fab_fa-reddit'                    => '<i class="fab fa-reddit"></i>',
						'fab_fa-reddit-alien'              => '<i class="fab fa-reddit-alien"></i>',
						'fab_fa-reddit-square'             => '<i class="fab fa-reddit-square"></i>',
						'fab_fa-redhat'                    => '<i class="fab fa-redhat"></i>',
						'fas_fa-redo'                      => '<i class="fas fa-redo"></i>',
						'fas_fa-redo-alt'                  => '<i class="fas fa-redo-alt"></i>',
						'fas_fa-registered'                => '<i class="fas fa-registered"></i>',
						'fab_fa-renren'                    => '<i class="fab fa-renren"></i>',
						'fas_fa-reply'                     => '<i class="fas fa-reply"></i>',
						'fas_fa-reply-all'                 => '<i class="fas fa-reply-all"></i>',
						'fab_fa-replyd'                    => '<i class="fab fa-replyd"></i>',
						'fas_fa-republican'                => '<i class="fas fa-republican"></i>',
						'fab_fa-researchgate'              => '<i class="fab fa-researchgate"></i>',
						'fab_fa-resolving'                 => '<i class="fab fa-resolving"></i>',
						'fas_fa-restroom'                  => '<i class="fas fa-restroom"></i>',
						'fas_fa-retweet'                   => '<i class="fas fa-retweet"></i>',
						'fab_fa-rev'                       => '<i class="fab fa-rev"></i>',
						'fas_fa-ribbon'                    => '<i class="fas fa-ribbon"></i>',
						'fas_fa-ring'                      => '<i class="fas fa-ring"></i>',
						'fas_fa-road'                      => '<i class="fas fa-road"></i>',
						'fas_fa-robot'                     => '<i class="fas fa-robot"></i>',
						'fas_fa-rocket'                    => '<i class="fas fa-rocket"></i>',
						'fab_fa-rocketchat'                => '<i class="fab fa-rocketchat"></i>',
						'fab_fa-rockrms'                   => '<i class="fab fa-rockrms"></i>',
						'fas_fa-route'                     => '<i class="fas fa-route"></i>',
						'fas_fa-rss'                       => '<i class="fas fa-rss"></i>',
						'fas_fa-rss-square'                => '<i class="fas fa-rss-square"></i>',
						'fas_fa-ruble-sign'                => '<i class="fas fa-ruble-sign"></i>',
						'fas_fa-ruler'                     => '<i class="fas fa-ruler"></i>',
						'fas_fa-ruler-combined'            => '<i class="fas fa-ruler-combined"></i>',
						'fas_fa-ruler-horizontal'          => '<i class="fas fa-ruler-horizontal"></i>',
						'fas_fa-ruler-vertical'            => '<i class="fas fa-ruler-vertical"></i>',
						'fas_fa-running'                   => '<i class="fas fa-running"></i>',
						'fas_fa-rupee-sign'                => '<i class="fas fa-rupee-sign"></i>',
						'fas_fa-sad-cry'                   => '<i class="fas fa-sad-cry"></i>',
						'fas_fa-sad-tear'                  => '<i class="fas fa-sad-tear"></i>',
						'fab_fa-safari'                    => '<i class="fab fa-safari"></i>',
						'fab_fa-sass'                      => '<i class="fab fa-sass"></i>',
						'fas_fa-satellite'                 => '<i class="fas fa-satellite"></i>',
						'fas_fa-satellite-dish'            => '<i class="fas fa-satellite-dish"></i>',
						'fas_fa-save'                      => '<i class="fas fa-save"></i>',
						'fab_fa-schlix'                    => '<i class="fab fa-schlix"></i>',
						'fas_fa-school'                    => '<i class="fas fa-school"></i>',
						'fas_fa-screwdriver'               => '<i class="fas fa-screwdriver"></i>',
						'fab_fa-scribd'                    => '<i class="fab fa-scribd"></i>',
						'fas_fa-scroll'                    => '<i class="fas fa-scroll"></i>',
						'fas_fa-sd-card'                   => '<i class="fas fa-sd-card"></i>',
						'fas_fa-search'                    => '<i class="fas fa-search"></i>',
						'fas_fa-search-dollar'             => '<i class="fas fa-search-dollar"></i>',
						'fas_fa-search-location'           => '<i class="fas fa-search-location"></i>',
						'fas_fa-search-minus'              => '<i class="fas fa-search-minus"></i>',
						'fas_fa-search-plus'               => '<i class="fas fa-search-plus"></i>',
						'fab_fa-searchengin'               => '<i class="fab fa-searchengin"></i>',
						'fas_fa-seedling'                  => '<i class="fas fa-seedling"></i>',
						'fab_fa-sellcast'                  => '<i class="fab fa-sellcast"></i>',
						'fab_fa-sellsy'                    => '<i class="fab fa-sellsy"></i>',
						'fas_fa-server'                    => '<i class="fas fa-server"></i>',
						'fab_fa-servicestack'              => '<i class="fab fa-servicestack"></i>',
						'fas_fa-shapes'                    => '<i class="fas fa-shapes"></i>',
						'fas_fa-share'                     => '<i class="fas fa-share"></i>',
						'fas_fa-share-alt'                 => '<i class="fas fa-share-alt"></i>',
						'fas_fa-share-alt-square'          => '<i class="fas fa-share-alt-square"></i>',
						'fas_fa-share-square'              => '<i class="fas fa-share-square"></i>',
						'fas_fa-shekel-sign'               => '<i class="fas fa-shekel-sign"></i>',
						'fas_fa-shield-alt'                => '<i class="fas fa-shield-alt"></i>',
						'fas_fa-ship'                      => '<i class="fas fa-ship"></i>',
						'fas_fa-shipping-fast'             => '<i class="fas fa-shipping-fast"></i>',
						'fab_fa-shirtsinbulk'              => '<i class="fab fa-shirtsinbulk"></i>',
						'fas_fa-shoe-prints'               => '<i class="fas fa-shoe-prints"></i>',
						'fas_fa-shopping-bag'              => '<i class="fas fa-shopping-bag"></i>',
						'fas_fa-shopping-basket'           => '<i class="fas fa-shopping-basket"></i>',
						'fas_fa-shopping-cart'             => '<i class="fas fa-shopping-cart"></i>',
						'fab_fa-shopware'                  => '<i class="fab fa-shopware"></i>',
						'fas_fa-shower'                    => '<i class="fas fa-shower"></i>',
						'fas_fa-shuttle-van'               => '<i class="fas fa-shuttle-van"></i>',
						'fas_fa-sign'                      => '<i class="fas fa-sign"></i>',
						'fas_fa-sign-in-alt'               => '<i class="fas fa-sign-in-alt"></i>',
						'fas_fa-sign-language'             => '<i class="fas fa-sign-language"></i>',
						'fas_fa-sign-out-alt'              => '<i class="fas fa-sign-out-alt"></i>',
						'fas_fa-signal'                    => '<i class="fas fa-signal"></i>',
						'fas_fa-signature'                 => '<i class="fas fa-signature"></i>',
						'fas_fa-sim-card'                  => '<i class="fas fa-sim-card"></i>',
						'fab_fa-simplybuilt'               => '<i class="fab fa-simplybuilt"></i>',
						'fab_fa-sistrix'                   => '<i class="fab fa-sistrix"></i>',
						'fas_fa-sitemap'                   => '<i class="fas fa-sitemap"></i>',
						'fab_fa-sith'                      => '<i class="fab fa-sith"></i>',
						'fas_fa-skating'                   => '<i class="fas fa-skating"></i>',
						'fab_fa-sketch'                    => '<i class="fab fa-sketch"></i>',
						'fas_fa-skiing'                    => '<i class="fas fa-skiing"></i>',
						'fas_fa-skiing-nordic'             => '<i class="fas fa-skiing-nordic"></i>',
						'fas_fa-skull'                     => '<i class="fas fa-skull"></i>',
						'fas_fa-skull-crossbones'          => '<i class="fas fa-skull-crossbones"></i>',
						'fab_fa-skyatlas'                  => '<i class="fab fa-skyatlas"></i>',
						'fab_fa-skype'                     => '<i class="fab fa-skype"></i>',
						'fab_fa-slack'                     => '<i class="fab fa-slack"></i>',
						'fab_fa-slack-hash'                => '<i class="fab fa-slack-hash"></i>',
						'fas_fa-slash'                     => '<i class="fas fa-slash"></i>',
						'fas_fa-sleigh'                    => '<i class="fas fa-sleigh"></i>',
						'fas_fa-sliders-h'                 => '<i class="fas fa-sliders-h"></i>',
						'fab_fa-slideshare'                => '<i class="fab fa-slideshare"></i>',
						'fas_fa-smile'                     => '<i class="fas fa-smile"></i>',
						'fas_fa-smile-beam'                => '<i class="fas fa-smile-beam"></i>',
						'fas_fa-smile-wink'                => '<i class="fas fa-smile-wink"></i>',
						'fas_fa-smog'                      => '<i class="fas fa-smog"></i>',
						'fas_fa-smoking'                   => '<i class="fas fa-smoking"></i>',
						'fas_fa-smoking-ban'               => '<i class="fas fa-smoking-ban"></i>',
						'fas_fa-sms'                       => '<i class="fas fa-sms"></i>',
						'fab_fa-snapchat'                  => '<i class="fab fa-snapchat"></i>',
						'fab_fa-snapchat-ghost'            => '<i class="fab fa-snapchat-ghost"></i>',
						'fab_fa-snapchat-square'           => '<i class="fab fa-snapchat-square"></i>',
						'fas_fa-snowboarding'              => '<i class="fas fa-snowboarding"></i>',
						'fas_fa-snowflake'                 => '<i class="fas fa-snowflake"></i>',
						'fas_fa-snowman'                   => '<i class="fas fa-snowman"></i>',
						'fas_fa-snowplow'                  => '<i class="fas fa-snowplow"></i>',
						'fas_fa-socks'                     => '<i class="fas fa-socks"></i>',
						'fas_fa-solar-panel'               => '<i class="fas fa-solar-panel"></i>',
						'fas_fa-sort'                      => '<i class="fas fa-sort"></i>',
						'fas_fa-sort-alpha-down'           => '<i class="fas fa-sort-alpha-down"></i>',
						'fas_fa-sort-alpha-up'             => '<i class="fas fa-sort-alpha-up"></i>',
						'fas_fa-sort-amount-down'          => '<i class="fas fa-sort-amount-down"></i>',
						'fas_fa-sort-amount-up'            => '<i class="fas fa-sort-amount-up"></i>',
						'fas_fa-sort-down'                 => '<i class="fas fa-sort-down"></i>',
						'fas_fa-sort-numeric-down'         => '<i class="fas fa-sort-numeric-down"></i>',
						'fas_fa-sort-numeric-up'           => '<i class="fas fa-sort-numeric-up"></i>',
						'fas_fa-sort-up'                   => '<i class="fas fa-sort-up"></i>',
						'fab_fa-soundcloud'                => '<i class="fab fa-soundcloud"></i>',
						'fab_fa-sourcetree'                => '<i class="fab fa-sourcetree"></i>',
						'fas_fa-spa'                       => '<i class="fas fa-spa"></i>',
						'fas_fa-space-shuttle'             => '<i class="fas fa-space-shuttle"></i>',
						'fab_fa-speakap'                   => '<i class="fab fa-speakap"></i>',
						'fas_fa-spider'                    => '<i class="fas fa-spider"></i>',
						'fas_fa-spinner'                   => '<i class="fas fa-spinner"></i>',
						'fas_fa-splotch'                   => '<i class="fas fa-splotch"></i>',
						'fab_fa-spotify'                   => '<i class="fab fa-spotify"></i>',
						'fas_fa-spray-can'                 => '<i class="fas fa-spray-can"></i>',
						'fas_fa-square'                    => '<i class="fas fa-square"></i>',
						'fas_fa-square-full'               => '<i class="fas fa-square-full"></i>',
						'fas_fa-square-root-alt'           => '<i class="fas fa-square-root-alt"></i>',
						'fab_fa-squarespace'               => '<i class="fab fa-squarespace"></i>',
						'fab_fa-stack-exchange'            => '<i class="fab fa-stack-exchange"></i>',
						'fab_fa-stack-overflow'            => '<i class="fab fa-stack-overflow"></i>',
						'fas_fa-stamp'                     => '<i class="fas fa-stamp"></i>',
						'fas_fa-star'                      => '<i class="fas fa-star"></i>',
						'fas_fa-star-and-crescent'         => '<i class="fas fa-star-and-crescent"></i>',
						'fas_fa-star-half'                 => '<i class="fas fa-star-half"></i>',
						'fas_fa-star-half-alt'             => '<i class="fas fa-star-half-alt"></i>',
						'fas_fa-star-of-david'             => '<i class="fas fa-star-of-david"></i>',
						'fas_fa-star-of-life'              => '<i class="fas fa-star-of-life"></i>',
						'fab_fa-staylinked'                => '<i class="fab fa-staylinked"></i>',
						'fab_fa-steam'                     => '<i class="fab fa-steam"></i>',
						'fab_fa-steam-square'              => '<i class="fab fa-steam-square"></i>',
						'fab_fa-steam-symbol'              => '<i class="fab fa-steam-symbol"></i>',
						'fas_fa-step-backward'             => '<i class="fas fa-step-backward"></i>',
						'fas_fa-step-forward'              => '<i class="fas fa-step-forward"></i>',
						'fas_fa-stethoscope'               => '<i class="fas fa-stethoscope"></i>',
						'fab_fa-sticker-mule'              => '<i class="fab fa-sticker-mule"></i>',
						'fas_fa-sticky-note'               => '<i class="fas fa-sticky-note"></i>',
						'fas_fa-stop'                      => '<i class="fas fa-stop"></i>',
						'fas_fa-stop-circle'               => '<i class="fas fa-stop-circle"></i>',
						'fas_fa-stopwatch'                 => '<i class="fas fa-stopwatch"></i>',
						'fas_fa-store'                     => '<i class="fas fa-store"></i>',
						'fas_fa-store-alt'                 => '<i class="fas fa-store-alt"></i>',
						'fab_fa-strava'                    => '<i class="fab fa-strava"></i>',
						'fas_fa-stream'                    => '<i class="fas fa-stream"></i>',
						'fas_fa-street-view'               => '<i class="fas fa-street-view"></i>',
						'fas_fa-strikethrough'             => '<i class="fas fa-strikethrough"></i>',
						'fab_fa-stripe'                    => '<i class="fab fa-stripe"></i>',
						'fab_fa-stripe-s'                  => '<i class="fab fa-stripe-s"></i>',
						'fas_fa-stroopwafel'               => '<i class="fas fa-stroopwafel"></i>',
						'fab_fa-studiovinari'              => '<i class="fab fa-studiovinari"></i>',
						'fab_fa-stumbleupon'               => '<i class="fab fa-stumbleupon"></i>',
						'fab_fa-stumbleupon-circle'        => '<i class="fab fa-stumbleupon-circle"></i>',
						'fas_fa-subscript'                 => '<i class="fas fa-subscript"></i>',
						'fas_fa-subway'                    => '<i class="fas fa-subway"></i>',
						'fas_fa-suitcase'                  => '<i class="fas fa-suitcase"></i>',
						'fas_fa-suitcase-rolling'          => '<i class="fas fa-suitcase-rolling"></i>',
						'fas_fa-sun'                       => '<i class="fas fa-sun"></i>',
						'fab_fa-superpowers'               => '<i class="fab fa-superpowers"></i>',
						'fas_fa-superscript'               => '<i class="fas fa-superscript"></i>',
						'fab_fa-supple'                    => '<i class="fab fa-supple"></i>',
						'fas_fa-surprise'                  => '<i class="fas fa-surprise"></i>',
						'fab_fa-suse'                      => '<i class="fab fa-suse"></i>',
						'fas_fa-swatchbook'                => '<i class="fas fa-swatchbook"></i>',
						'fas_fa-swimmer'                   => '<i class="fas fa-swimmer"></i>',
						'fas_fa-swimming-pool'             => '<i class="fas fa-swimming-pool"></i>',
						'fas_fa-synagogue'                 => '<i class="fas fa-synagogue"></i>',
						'fas_fa-sync'                      => '<i class="fas fa-sync"></i>',
						'fas_fa-sync-alt'                  => '<i class="fas fa-sync-alt"></i>',
						'fas_fa-syringe'                   => '<i class="fas fa-syringe"></i>',
						'fas_fa-table'                     => '<i class="fas fa-table"></i>',
						'fas_fa-table-tennis'              => '<i class="fas fa-table-tennis"></i>',
						'fas_fa-tablet'                    => '<i class="fas fa-tablet"></i>',
						'fas_fa-tablet-alt'                => '<i class="fas fa-tablet-alt"></i>',
						'fas_fa-tablets'                   => '<i class="fas fa-tablets"></i>',
						'fas_fa-tachometer-alt'            => '<i class="fas fa-tachometer-alt"></i>',
						'fas_fa-tag'                       => '<i class="fas fa-tag"></i>',
						'fas_fa-tags'                      => '<i class="fas fa-tags"></i>',
						'fas_fa-tape'                      => '<i class="fas fa-tape"></i>',
						'fas_fa-tasks'                     => '<i class="fas fa-tasks"></i>',
						'fas_fa-taxi'                      => '<i class="fas fa-taxi"></i>',
						'fab_fa-teamspeak'                 => '<i class="fab fa-teamspeak"></i>',
						'fas_fa-teeth'                     => '<i class="fas fa-teeth"></i>',
						'fas_fa-teeth-open'                => '<i class="fas fa-teeth-open"></i>',
						'fab_fa-telegram'                  => '<i class="fab fa-telegram"></i>',
						'fab_fa-telegram-plane'            => '<i class="fab fa-telegram-plane"></i>',
						'fas_fa-temperature-high'          => '<i class="fas fa-temperature-high"></i>',
						'fas_fa-temperature-low'           => '<i class="fas fa-temperature-low"></i>',
						'fab_fa-tencent-weibo'             => '<i class="fab fa-tencent-weibo"></i>',
						'fas_fa-tenge'                     => '<i class="fas fa-tenge"></i>',
						'fas_fa-terminal'                  => '<i class="fas fa-terminal"></i>',
						'fas_fa-text-height'               => '<i class="fas fa-text-height"></i>',
						'fas_fa-text-width'                => '<i class="fas fa-text-width"></i>',
						'fas_fa-th'                        => '<i class="fas fa-th"></i>',
						'fas_fa-th-large'                  => '<i class="fas fa-th-large"></i>',
						'fas_fa-th-list'                   => '<i class="fas fa-th-list"></i>',
						'fab_fa-the-red-yeti'              => '<i class="fab fa-the-red-yeti"></i>',
						'fas_fa-theater-masks'             => '<i class="fas fa-theater-masks"></i>',
						'fab_fa-themeco'                   => '<i class="fab fa-themeco"></i>',
						'fab_fa-themeisle'                 => '<i class="fab fa-themeisle"></i>',
						'fas_fa-thermometer'               => '<i class="fas fa-thermometer"></i>',
						'fas_fa-thermometer-empty'         => '<i class="fas fa-thermometer-empty"></i>',
						'fas_fa-thermometer-full'          => '<i class="fas fa-thermometer-full"></i>',
						'fas_fa-thermometer-half'          => '<i class="fas fa-thermometer-half"></i>',
						'fas_fa-thermometer-quarter'       => '<i class="fas fa-thermometer-quarter"></i>',
						'fas_fa-thermometer-three-quarters' => '<i class="fas fa-thermometer-three-quarters"></i>',
						'fab_fa-think-peaks'               => '<i class="fab fa-think-peaks"></i>',
						'fas_fa-thumbs-down'               => '<i class="fas fa-thumbs-down"></i>',
						'fas_fa-thumbs-up'                 => '<i class="fas fa-thumbs-up"></i>',
						'fas_fa-thumbtack'                 => '<i class="fas fa-thumbtack"></i>',
						'fas_fa-ticket-alt'                => '<i class="fas fa-ticket-alt"></i>',
						'fas_fa-times'                     => '<i class="fas fa-times"></i>',
						'fas_fa-times-circle'              => '<i class="fas fa-times-circle"></i>',
						'fas_fa-tint'                      => '<i class="fas fa-tint"></i>',
						'fas_fa-tint-slash'                => '<i class="fas fa-tint-slash"></i>',
						'fas_fa-tired'                     => '<i class="fas fa-tired"></i>',
						'fas_fa-toggle-off'                => '<i class="fas fa-toggle-off"></i>',
						'fas_fa-toggle-on'                 => '<i class="fas fa-toggle-on"></i>',
						'fas_fa-toilet'                    => '<i class="fas fa-toilet"></i>',
						'fas_fa-toilet-paper'              => '<i class="fas fa-toilet-paper"></i>',
						'fas_fa-toolbox'                   => '<i class="fas fa-toolbox"></i>',
						'fas_fa-tools'                     => '<i class="fas fa-tools"></i>',
						'fas_fa-tooth'                     => '<i class="fas fa-tooth"></i>',
						'fas_fa-torah'                     => '<i class="fas fa-torah"></i>',
						'fas_fa-torii-gate'                => '<i class="fas fa-torii-gate"></i>',
						'fas_fa-tractor'                   => '<i class="fas fa-tractor"></i>',
						'fab_fa-trade-federation'          => '<i class="fab fa-trade-federation"></i>',
						'fas_fa-trademark'                 => '<i class="fas fa-trademark"></i>',
						'fas_fa-traffic-light'             => '<i class="fas fa-traffic-light"></i>',
						'fas_fa-train'                     => '<i class="fas fa-train"></i>',
						'fas_fa-tram'                      => '<i class="fas fa-tram"></i>',
						'fas_fa-transgender'               => '<i class="fas fa-transgender"></i>',
						'fas_fa-transgender-alt'           => '<i class="fas fa-transgender-alt"></i>',
						'fas_fa-trash'                     => '<i class="fas fa-trash"></i>',
						'fas_fa-trash-alt'                 => '<i class="fas fa-trash-alt"></i>',
						'fas_fa-trash-restore'             => '<i class="fas fa-trash-restore"></i>',
						'fas_fa-trash-restore-alt'         => '<i class="fas fa-trash-restore-alt"></i>',
						'fas_fa-tree'                      => '<i class="fas fa-tree"></i>',
						'fab_fa-trello'                    => '<i class="fab fa-trello"></i>',
						'fab_fa-tripadvisor'               => '<i class="fab fa-tripadvisor"></i>',
						'fas_fa-trophy'                    => '<i class="fas fa-trophy"></i>',
						'fas_fa-truck'                     => '<i class="fas fa-truck"></i>',
						'fas_fa-truck-loading'             => '<i class="fas fa-truck-loading"></i>',
						'fas_fa-truck-monster'             => '<i class="fas fa-truck-monster"></i>',
						'fas_fa-truck-moving'              => '<i class="fas fa-truck-moving"></i>',
						'fas_fa-truck-pickup'              => '<i class="fas fa-truck-pickup"></i>',
						'fas_fa-tshirt'                    => '<i class="fas fa-tshirt"></i>',
						'fas_fa-tty'                       => '<i class="fas fa-tty"></i>',
						'fab_fa-tumblr'                    => '<i class="fab fa-tumblr"></i>',
						'fab_fa-tumblr-square'             => '<i class="fab fa-tumblr-square"></i>',
						'fas_fa-tv'                        => '<i class="fas fa-tv"></i>',
						'fab_fa-twitch'                    => '<i class="fab fa-twitch"></i>',
						'fab_fa-twitter'                   => '<i class="fab fa-twitter"></i>',
						'fab_fa-twitter-square'            => '<i class="fab fa-twitter-square"></i>',
						'fab_fa-typo'                      => '<i class="fab fa-typo"></i>',
						'fab_fa-uber'                      => '<i class="fab fa-uber"></i>',
						'fab_fa-ubuntu'                    => '<i class="fab fa-ubuntu"></i>',
						'fab_fa-uikit'                     => '<i class="fab fa-uikit"></i>',
						'fas_fa-umbrella'                  => '<i class="fas fa-umbrella"></i>',
						'fas_fa-umbrella-beach'            => '<i class="fas fa-umbrella-beach"></i>',
						'fas_fa-underline'                 => '<i class="fas fa-underline"></i>',
						'fas_fa-undo'                      => '<i class="fas fa-undo"></i>',
						'fas_fa-undo-alt'                  => '<i class="fas fa-undo-alt"></i>',
						'fab_fa-uniregistry'               => '<i class="fab fa-uniregistry"></i>',
						'fas_fa-universal-access'          => '<i class="fas fa-universal-access"></i>',
						'fas_fa-university'                => '<i class="fas fa-university"></i>',
						'fas_fa-unlink'                    => '<i class="fas fa-unlink"></i>',
						'fas_fa-unlock'                    => '<i class="fas fa-unlock"></i>',
						'fas_fa-unlock-alt'                => '<i class="fas fa-unlock-alt"></i>',
						'fab_fa-untappd'                   => '<i class="fab fa-untappd"></i>',
						'fas_fa-upload'                    => '<i class="fas fa-upload"></i>',
						'fab_fa-ups'                       => '<i class="fab fa-ups"></i>',
						'fab_fa-usb'                       => '<i class="fab fa-usb"></i>',
						'fas_fa-user'                      => '<i class="fas fa-user"></i>',
						'fas_fa-user-alt'                  => '<i class="fas fa-user-alt"></i>',
						'fas_fa-user-alt-slash'            => '<i class="fas fa-user-alt-slash"></i>',
						'fas_fa-user-astronaut'            => '<i class="fas fa-user-astronaut"></i>',
						'fas_fa-user-check'                => '<i class="fas fa-user-check"></i>',
						'fas_fa-user-circle'               => '<i class="fas fa-user-circle"></i>',
						'fas_fa-user-clock'                => '<i class="fas fa-user-clock"></i>',
						'fas_fa-user-cog'                  => '<i class="fas fa-user-cog"></i>',
						'fas_fa-user-edit'                 => '<i class="fas fa-user-edit"></i>',
						'fas_fa-user-friends'              => '<i class="fas fa-user-friends"></i>',
						'fas_fa-user-graduate'             => '<i class="fas fa-user-graduate"></i>',
						'fas_fa-user-injured'              => '<i class="fas fa-user-injured"></i>',
						'fas_fa-user-lock'                 => '<i class="fas fa-user-lock"></i>',
						'fas_fa-user-md'                   => '<i class="fas fa-user-md"></i>',
						'fas_fa-user-minus'                => '<i class="fas fa-user-minus"></i>',
						'fas_fa-user-ninja'                => '<i class="fas fa-user-ninja"></i>',
						'fas_fa-user-nurse'                => '<i class="fas fa-user-nurse"></i>',
						'fas_fa-user-plus'                 => '<i class="fas fa-user-plus"></i>',
						'fas_fa-user-secret'               => '<i class="fas fa-user-secret"></i>',
						'fas_fa-user-shield'               => '<i class="fas fa-user-shield"></i>',
						'fas_fa-user-slash'                => '<i class="fas fa-user-slash"></i>',
						'fas_fa-user-tag'                  => '<i class="fas fa-user-tag"></i>',
						'fas_fa-user-tie'                  => '<i class="fas fa-user-tie"></i>',
						'fas_fa-user-times'                => '<i class="fas fa-user-times"></i>',
						'fas_fa-users'                     => '<i class="fas fa-users"></i>',
						'fas_fa-users-cog'                 => '<i class="fas fa-users-cog"></i>',
						'fab_fa-usps'                      => '<i class="fab fa-usps"></i>',
						'fab_fa-ussunnah'                  => '<i class="fab fa-ussunnah"></i>',
						'fas_fa-utensil-spoon'             => '<i class="fas fa-utensil-spoon"></i>',
						'fas_fa-utensils'                  => '<i class="fas fa-utensils"></i>',
						'fab_fa-vaadin'                    => '<i class="fab fa-vaadin"></i>',
						'fas_fa-vector-square'             => '<i class="fas fa-vector-square"></i>',
						'fas_fa-venus'                     => '<i class="fas fa-venus"></i>',
						'fas_fa-venus-double'              => '<i class="fas fa-venus-double"></i>',
						'fas_fa-venus-mars'                => '<i class="fas fa-venus-mars"></i>',
						'fab_fa-viacoin'                   => '<i class="fab fa-viacoin"></i>',
						'fab_fa-viadeo'                    => '<i class="fab fa-viadeo"></i>',
						'fab_fa-viadeo-square'             => '<i class="fab fa-viadeo-square"></i>',
						'fas_fa-vial'                      => '<i class="fas fa-vial"></i>',
						'fas_fa-vials'                     => '<i class="fas fa-vials"></i>',
						'fab_fa-viber'                     => '<i class="fab fa-viber"></i>',
						'fas_fa-video'                     => '<i class="fas fa-video"></i>',
						'fas_fa-video-slash'               => '<i class="fas fa-video-slash"></i>',
						'fas_fa-vihara'                    => '<i class="fas fa-vihara"></i>',
						'fab_fa-vimeo'                     => '<i class="fab fa-vimeo"></i>',
						'fab_fa-vimeo-square'              => '<i class="fab fa-vimeo-square"></i>',
						'fab_fa-vimeo-v'                   => '<i class="fab fa-vimeo-v"></i>',
						'fab_fa-vine'                      => '<i class="fab fa-vine"></i>',
						'fab_fa-vk'                        => '<i class="fab fa-vk"></i>',
						'fab_fa-vnv'                       => '<i class="fab fa-vnv"></i>',
						'fas_fa-volleyball-ball'           => '<i class="fas fa-volleyball-ball"></i>',
						'fas_fa-volume-down'               => '<i class="fas fa-volume-down"></i>',
						'fas_fa-volume-mute'               => '<i class="fas fa-volume-mute"></i>',
						'fas_fa-volume-off'                => '<i class="fas fa-volume-off"></i>',
						'fas_fa-volume-up'                 => '<i class="fas fa-volume-up"></i>',
						'fas_fa-vote-yea'                  => '<i class="fas fa-vote-yea"></i>',
						'fas_fa-vr-cardboard'              => '<i class="fas fa-vr-cardboard"></i>',
						'fab_fa-vuejs'                     => '<i class="fab fa-vuejs"></i>',
						'fas_fa-walking'                   => '<i class="fas fa-walking"></i>',
						'fas_fa-wallet'                    => '<i class="fas fa-wallet"></i>',
						'fas_fa-warehouse'                 => '<i class="fas fa-warehouse"></i>',
						'fas_fa-water'                     => '<i class="fas fa-water"></i>',
						'fab_fa-weebly'                    => '<i class="fab fa-weebly"></i>',
						'fab_fa-weibo'                     => '<i class="fab fa-weibo"></i>',
						'fas_fa-weight'                    => '<i class="fas fa-weight"></i>',
						'fas_fa-weight-hanging'            => '<i class="fas fa-weight-hanging"></i>',
						'fab_fa-weixin'                    => '<i class="fab fa-weixin"></i>',
						'fab_fa-whatsapp'                  => '<i class="fab fa-whatsapp"></i>',
						'fab_fa-whatsapp-square'           => '<i class="fab fa-whatsapp-square"></i>',
						'fas_fa-wheelchair'                => '<i class="fas fa-wheelchair"></i>',
						'fab_fa-whmcs'                     => '<i class="fab fa-whmcs"></i>',
						'fas_fa-wifi'                      => '<i class="fas fa-wifi"></i>',
						'fab_fa-wikipedia-w'               => '<i class="fab fa-wikipedia-w"></i>',
						'fas_fa-wind'                      => '<i class="fas fa-wind"></i>',
						'fas_fa-window-close'              => '<i class="fas fa-window-close"></i>',
						'fas_fa-window-maximize'           => '<i class="fas fa-window-maximize"></i>',
						'fas_fa-window-minimize'           => '<i class="fas fa-window-minimize"></i>',
						'fas_fa-window-restore'            => '<i class="fas fa-window-restore"></i>',
						'fab_fa-windows'                   => '<i class="fab fa-windows"></i>',
						'fas_fa-wine-bottle'               => '<i class="fas fa-wine-bottle"></i>',
						'fas_fa-wine-glass'                => '<i class="fas fa-wine-glass"></i>',
						'fas_fa-wine-glass-alt'            => '<i class="fas fa-wine-glass-alt"></i>',
						'fab_fa-wix'                       => '<i class="fab fa-wix"></i>',
						'fab_fa-wizards-of-the-coast'      => '<i class="fab fa-wizards-of-the-coast"></i>',
						'fab_fa-wolf-pack-battalion'       => '<i class="fab fa-wolf-pack-battalion"></i>',
						'fas_fa-won-sign'                  => '<i class="fas fa-won-sign"></i>',
						'fab_fa-wordpress'                 => '<i class="fab fa-wordpress"></i>',
						'fab_fa-wordpress-simple'          => '<i class="fab fa-wordpress-simple"></i>',
						'fab_fa-wpbeginner'                => '<i class="fab fa-wpbeginner"></i>',
						'fab_fa-wpexplorer'                => '<i class="fab fa-wpexplorer"></i>',
						'fab_fa-wpforms'                   => '<i class="fab fa-wpforms"></i>',
						'fab_fa-wpressr'                   => '<i class="fab fa-wpressr"></i>',
						'fas_fa-wrench'                    => '<i class="fas fa-wrench"></i>',
						'fas_fa-x-ray'                     => '<i class="fas fa-x-ray"></i>',
						'fab_fa-xbox'                      => '<i class="fab fa-xbox"></i>',
						'fab_fa-xing'                      => '<i class="fab fa-xing"></i>',
						'fab_fa-xing-square'               => '<i class="fab fa-xing-square"></i>',
						'fab_fa-y-combinator'              => '<i class="fab fa-y-combinator"></i>',
						'fab_fa-yahoo'                     => '<i class="fab fa-yahoo"></i>',
						'fab_fa-yandex'                    => '<i class="fab fa-yandex"></i>',
						'fab_fa-yandex-international'      => '<i class="fab fa-yandex-international"></i>',
						'fab_fa-yarn'                      => '<i class="fab fa-yarn"></i>',
						'fab_fa-yelp'                      => '<i class="fab fa-yelp"></i>',
						'fas_fa-yen-sign'                  => '<i class="fas fa-yen-sign"></i>',
						'fas_fa-yin-yang'                  => '<i class="fas fa-yin-yang"></i>',
						'fab_fa-yoast'                     => '<i class="fab fa-yoast"></i>',
						'fab_fa-youtube'                   => '<i class="fab fa-youtube"></i>',
						'fab_fa-youtube-square'            => '<i class="fab fa-youtube-square"></i>',
						'fab_fa-zhihu'                     => '<i class="fab fa-zhihu"></i>',
					),
				),
			),
		);
	}

}
